import React, { useEffect } from 'react';
import { Icon } from '../Icon';
import { Typography } from '../Typography';
import { StyledAlertContainer, StyledAlertContentColumn, StyledAlertCloseIconContainer } from './AlertStyle';
var iconNameStatusMap = {
  success: 'ri-checkbox-circle-fill',
  info: 'ri-information-fill',
  warning: 'ri-error-warning-fill',
  error: 'ri-error-warning-fill'
};
export var Alert = /*#__PURE__*/React.forwardRef(function Alert(_ref, ref) {
  var show = _ref.show,
    title = _ref.title,
    content = _ref.content,
    status = _ref.status,
    _ref$duration = _ref.duration,
    duration = _ref$duration === void 0 ? 4000 : _ref$duration,
    children = _ref.children,
    zIndex = _ref.zIndex,
    position = _ref.position,
    onDismissed = _ref.onDismissed;
  useEffect(function () {
    if (!show || duration === Infinity) {
      return;
    }
    var timeId = setTimeout(function () {
      onDismissed == null ? void 0 : onDismissed();
    }, duration);
    return function () {
      clearTimeout(timeId);
    };
  }, [duration, onDismissed, show]);
  var hasTitle = !!title;
  var iconStatus = iconNameStatusMap[status];
  if (status && !iconStatus) {
    console.warn("Status \"" + status + "\" is not a valid Alert status, \"info\" will be used instead");
  }
  var iconName = iconStatus || iconNameStatusMap['info'];
  if (!show) {
    return null;
  }
  return /*#__PURE__*/React.createElement(StyledAlertContainer, {
    ref: ref,
    role: "alert",
    "data-titled": hasTitle,
    "data-status": status || 'info',
    zIndex: zIndex,
    position: position
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Icon, {
    name: iconName
  })), /*#__PURE__*/React.createElement("div", null, hasTitle && /*#__PURE__*/React.createElement(StyledAlertContentColumn, null, /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "subtitle1"
  }, title)), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(StyledAlertContentColumn, null, /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "body1"
  }, content))), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(StyledAlertContentColumn, null, /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "body1"
  }, children)))), /*#__PURE__*/React.createElement(StyledAlertCloseIconContainer, {
    role: "button",
    onClick: function onClick() {
      return onDismissed == null ? void 0 : onDismissed();
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-close"
  })));
});