import React, { useCallback, useEffect, useRef, useState } from 'react';
import { Icon } from '../Icon';
import { Neutral } from '../utilities/colors';
import { ArrowsContainer, CarouselContainer, Indicator, IndicatorsContainer, ItemsContainer, NextArrow, PreviousArrow, SlideContainer } from './CarouselStyle';
export var Carousel = function Carousel(_ref) {
  var _ref$autoRotate = _ref.autoRotate,
    autoRotate = _ref$autoRotate === void 0 ? false : _ref$autoRotate,
    children = _ref.children,
    aspectRatio = _ref.aspectRatio,
    height = _ref.height,
    width = _ref.width,
    _ref$indicatorPositio = _ref.indicatorPosition,
    indicatorPosition = _ref$indicatorPositio === void 0 ? 'outer' : _ref$indicatorPositio,
    _ref$indicatorType = _ref.indicatorType,
    indicatorType = _ref$indicatorType === void 0 ? 'line' : _ref$indicatorType,
    _ref$duration = _ref.duration,
    duration = _ref$duration === void 0 ? 3000 : _ref$duration,
    _ref$showArrows = _ref.showArrows,
    showArrows = _ref$showArrows === void 0 ? true : _ref$showArrows;
  var slideRef = useRef(null);
  var slideTimeout = useRef();
  var _useState = useState(0),
    activeIndex = _useState[0],
    setActiveIndex = _useState[1];
  var _useState2 = useState(autoRotate),
    hideArrows = _useState2[0],
    setHideArrows = _useState2[1];
  var childrenList = React.Children.toArray(children).filter(function (child) {
    return /*#__PURE__*/React.isValidElement(child);
  });
  var childrenLength = childrenList.length;
  var updateActiveIndex = useCallback(function (index) {
    if (index < 0) {
      setActiveIndex(childrenLength - 1);
      return;
    }
    if (index === childrenLength) {
      setActiveIndex(0);
      return;
    }
    setActiveIndex(index);
  }, [childrenLength]);
  var handlePreviousClick = function handlePreviousClick() {
    updateActiveIndex(activeIndex - 1);
  };
  var handleNextClick = function handleNextClick() {
    updateActiveIndex(activeIndex + 1);
  };
  var handleMouseEnter = function handleMouseEnter() {
    if (autoRotate) {
      setHideArrows(false);
      return;
    }
  };
  var handleMouseLeave = function handleMouseLeave() {
    if (autoRotate) {
      setHideArrows(true);
      return;
    }
  };
  useEffect(function () {
    if (autoRotate) {
      if (slideTimeout.current) clearTimeout(slideTimeout.current);
      slideTimeout.current = setTimeout(function () {
        updateActiveIndex(activeIndex + 1);
      }, duration);
    }
  }, [activeIndex, autoRotate, duration, updateActiveIndex]);
  return /*#__PURE__*/React.createElement(CarouselContainer, {
    aspectRatio: aspectRatio ? (aspectRatio == null ? void 0 : aspectRatio.width) + "/" + (aspectRatio == null ? void 0 : aspectRatio.height) : null,
    height: height,
    width: width,
    onMouseEnter: handleMouseEnter,
    onMouseLeave: handleMouseLeave
  }, /*#__PURE__*/React.createElement(SlideContainer, {
    ref: slideRef,
    aspectRatio: aspectRatio ? (aspectRatio == null ? void 0 : aspectRatio.width) + "/" + (aspectRatio == null ? void 0 : aspectRatio.height) : null,
    height: height,
    width: width
  }, /*#__PURE__*/React.createElement(ItemsContainer, {
    activeIndex: activeIndex
  }, childrenList)), showArrows && /*#__PURE__*/React.createElement(ArrowsContainer, {
    "data-hidden": hideArrows
  }, /*#__PURE__*/React.createElement(PreviousArrow, {
    onClick: handlePreviousClick
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-arrow-m-left-line",
    fill: Neutral.B40
  })), /*#__PURE__*/React.createElement(NextArrow, {
    onClick: handleNextClick
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-arrow-m-right-line",
    fill: Neutral.B40
  }))), !!indicatorType && /*#__PURE__*/React.createElement(IndicatorsContainer, {
    indicatorType: indicatorType,
    indicatorPosition: indicatorPosition
  }, /*#__PURE__*/React.createElement("div", null, Array.from(Array(childrenLength).keys()).map(function (n) {
    var isActive = activeIndex === n;
    return /*#__PURE__*/React.createElement(Indicator, {
      indicatorType: indicatorType,
      key: "carousel-indicator-" + n,
      onClick: function onClick() {
        return updateActiveIndex(n);
      },
      className: isActive ? 'active' : null
    });
  }))));
};