import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["label", "id", "checked", "onChange", "disabled", "indeterminate", "hasError", "helpText", "isPadded", "isControlled"];
import React, { useEffect, useRef, useState } from 'react';
import { StyledCheckbox, StyledCheckboxContainer, StyledColumn, StyledContainer, StyledLeftColumn, StyledRow } from './CheckboxStyle';
import { noop } from 'lodash-es';
import { Icon } from '../Icon';
import { Typography } from '../Typography';
import nextId from 'react-id-generator';
export var Checkbox = /*#__PURE__*/React.forwardRef(function Checkbox(_ref, ref) {
  var label = _ref.label,
    id = _ref.id,
    checked = _ref.checked,
    onChange = _ref.onChange,
    disabled = _ref.disabled,
    indeterminate = _ref.indeterminate,
    hasError = _ref.hasError,
    helpText = _ref.helpText,
    _ref$isPadded = _ref.isPadded,
    isPadded = _ref$isPadded === void 0 ? true : _ref$isPadded,
    _ref$isControlled = _ref.isControlled,
    isControlled = _ref$isControlled === void 0 ? false : _ref$isControlled,
    otherProps = _objectWithoutPropertiesLoose(_ref, _excluded);
  var randomId = nextId('glints-checkbox');
  var checkBoxId = id ? id : randomId;
  var labelId = "label-" + checkBoxId;
  var inputNode = useRef(null);
  var _useState = useState(false),
    checkedState = _useState[0],
    setCheckedState = _useState[1];
  var _useState2 = useState(false),
    isFocused = _useState2[0],
    setIsFocused = _useState2[1];
  var checkedIcon = indeterminate ? 'ri-checkbox-indeterminate-fill' : 'ri-checkbox-fill';
  useEffect(function () {
    var value = indeterminate ? 'mixed' : checked;
    setCheckedState(value);
  }, [checked, indeterminate]);
  var handleClick = function handleClick() {
    if (!inputNode.current || disabled) {
      return;
    }
    var checkedValue = !checkedState;
    setCheckedState(checkedValue);
    onChange == null ? void 0 : onChange(checkedValue, checkBoxId);
  };
  return /*#__PURE__*/React.createElement(StyledContainer, {
    ref: ref,
    "aria-disabled": disabled,
    "data-error": hasError,
    "data-spacing": isPadded
  }, /*#__PURE__*/React.createElement(StyledRow, {
    className: "glints-checkbox-styled-row"
  }, /*#__PURE__*/React.createElement(StyledLeftColumn, null, /*#__PURE__*/React.createElement(StyledCheckboxContainer, null, /*#__PURE__*/React.createElement(StyledCheckbox, {
    role: "checkbox",
    "aria-labelledby": labelId,
    "aria-checked": isControlled ? checked : checkedState,
    "data-focus": isFocused,
    onClick: function onClick() {
      return handleClick();
    },
    onMouseDown: function onMouseDown() {
      return setIsFocused(false);
    },
    onMouseUp: function onMouseUp() {
      return setIsFocused(false);
    },
    hasError: hasError
  }, /*#__PURE__*/React.createElement("input", _extends({
    ref: inputNode,
    disabled: disabled,
    id: checkBoxId,
    type: "checkbox",
    onChange: noop,
    checked: checked,
    onFocus: function onFocus() {
      return setIsFocused(true);
    },
    onBlur: function onBlur() {
      return setIsFocused(false);
    }
  }, otherProps))), /*#__PURE__*/React.createElement(Icon, {
    name: checkedIcon
  }))), /*#__PURE__*/React.createElement(StyledColumn, null, /*#__PURE__*/React.createElement("label", {
    id: labelId,
    htmlFor: checkBoxId,
    onClick: function onClick(e) {
      e.preventDefault();
      handleClick();
    },
    onMouseDown: function onMouseDown(e) {
      return e.preventDefault();
    },
    onMouseUp: function onMouseUp(e) {
      return e.preventDefault();
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "body1"
  }, label)))), helpText && /*#__PURE__*/React.createElement(StyledRow, null, /*#__PURE__*/React.createElement(StyledLeftColumn, null), /*#__PURE__*/React.createElement(StyledColumn, {
    className: "help-text"
  }, /*#__PURE__*/React.createElement(Typography, {
    as: "span",
    variant: "subtitle2"
  }, helpText))));
});