import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["locale", "value", "allowEmptyValue", "showPrefix", "onChange", "currencyCode", "currencySymbol"];
import React from 'react';
import { Input } from '../Input/Input';
export var CurrencyInput = /*#__PURE__*/React.forwardRef(function CurrencyInput(_ref, ref) {
  var _formatter$format;
  var _ref$locale = _ref.locale,
    locale = _ref$locale === void 0 ? 'en' : _ref$locale,
    value = _ref.value,
    _ref$allowEmptyValue = _ref.allowEmptyValue,
    allowEmptyValue = _ref$allowEmptyValue === void 0 ? false : _ref$allowEmptyValue,
    _ref$showPrefix = _ref.showPrefix,
    showPrefix = _ref$showPrefix === void 0 ? true : _ref$showPrefix,
    onChange = _ref.onChange,
    currencyCode = _ref.currencyCode,
    currencySymbol = _ref.currencySymbol,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  // eslint-disable-next-line @typescript-eslint/ban-ts-comment
  // @ts-ignore
  var supportedLocale = Intl.ListFormat.supportedLocalesOf(locale);
  var localeValue = supportedLocale.length > 0 ? supportedLocale[0] : 'en';
  if (supportedLocale.length === 0) {
    console.warn("Locale value of " + locale + " is unsupported, \"en\" will be used");
  }
  var formatter = new Intl.NumberFormat(localeValue);
  var getRawNumber = function getRawNumber(value) {
    if (typeof value === 'number') {
      return value;
    }
    var parts = formatter.formatToParts(1000.1);
    var thousandSeparator = parts[1].value;
    var decimalSeparator = parts[3].value;
    var cleanedValue = parseFloat(value.replace(new RegExp('\\' + thousandSeparator, 'g'), '').replace(new RegExp('\\' + decimalSeparator), '.'));
    return Number.isNaN(cleanedValue) ? 0 : cleanedValue;
  };
  var getCurrencySymbol = function getCurrencySymbol(locale, currencyCode, currencySymbol) {
    if (currencySymbol) {
      return currencySymbol;
    }
    try {
      var _parts$find;
      var _formatter = new Intl.NumberFormat(locale, {
        style: 'currency',
        currency: currencyCode
      });
      var parts = _formatter.formatToParts(0);
      var returnedCurrencySymbol = (_parts$find = parts.find(function (part) {
        return part.type === 'currency';
      })) == null ? void 0 : _parts$find.value;
      return returnedCurrencySymbol;
    } catch (e) {
      console.warn("Currency code of " + currencyCode + " is unsupported, \"$\" will be used");
    }
    return '$';
  };
  var formattedValue = allowEmptyValue && value === null ? null : (_formatter$format = formatter.format(getRawNumber((value != null ? value : 0).toString()))) != null ? _formatter$format : '';
  var handleChange = function handleChange(e) {
    if (allowEmptyValue && e.currentTarget.value === '') {
      onChange(null);
      return;
    }
    var rawValue = getRawNumber(e.currentTarget.value);
    onChange(rawValue);
  };
  return /*#__PURE__*/React.createElement(Input, _extends({
    ref: ref,
    type: "text",
    prefix: showPrefix && /*#__PURE__*/React.createElement("div", null, getCurrencySymbol(localeValue, currencyCode, currencySymbol))
  }, props, {
    value: formattedValue,
    onChange: handleChange
  }));
});