import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["headings", "totals", "onSortChanged", "children", "emptyState", "loading", "loadingLabel"];
function _createForOfIteratorHelperLoose(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (it) return (it = it.call(o)).next.bind(it); if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; return function () { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import React from 'react';
import { Spinner } from '../Spinner';
import { Typography } from '../Typography';
import { StyledDataTableContainer, StyledLoaderWrapper, StyledSpinnerContainer, StyledTable, StyledTableCell, StyledTableFooterRow, StyledTableLoadingRow, StyledTableRow } from './DataTableStyle';
import { TableCell } from './TableCell';
import { TableFooter } from './TableFooter';
import { TableHeader } from './TableHeader';
import { TableRow } from './TableRow';
var DataTableComponent = /*#__PURE__*/React.forwardRef(function DataTable(_ref, ref) {
  var headings = _ref.headings,
    totals = _ref.totals,
    onSortChanged = _ref.onSortChanged,
    children = _ref.children,
    emptyState = _ref.emptyState,
    loading = _ref.loading,
    _ref$loadingLabel = _ref.loadingLabel,
    loadingLabel = _ref$loadingLabel === void 0 ? 'loading' : _ref$loadingLabel,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var handleSortChanged = function handleSortChanged(context, sortDirection) {
    onSortChanged == null ? void 0 : onSortChanged(context, sortDirection);
  };
  var rowHeaderMarkup = headings.map(function (heading, index) {
    var id = heading.id,
      title = heading.title,
      defaultSortDirection = heading.defaultSortDirection,
      align = heading.align;
    var key = "table-header-heading-" + title + "-" + index;
    if (onSortChanged && typeof title !== 'string' && !id) console.warn("Warning: If the title in TableHeading is of type ReactNode and you require sorting functionality, please make sure to provide 'id' for the TableHeading.");
    return /*#__PURE__*/React.createElement(TableHeader, {
      key: key,
      title: title,
      sortDirection: defaultSortDirection,
      align: align,
      onSort: function onSort(sortDirection) {
        return handleSortChanged(id || title.toString(), sortDirection);
      }
    });
  });
  var totalsRowMarkup = totals ? totals.map(function (total, index) {
    var _ref2 = total || {
        title: ''
      },
      title = _ref2.title,
      align = _ref2.align;
    var key = total + "-" + index;
    return /*#__PURE__*/React.createElement(TableCell, {
      key: key,
      align: align
    }, /*#__PURE__*/React.createElement(Typography, {
      as: "div",
      variant: "caption"
    }, title));
  }) : null;
  var footer;
  var rows = [];
  for (var _iterator = _createForOfIteratorHelperLoose(React.Children.toArray(children)), _step; !(_step = _iterator()).done;) {
    var child = _step.value;
    var reactEl = child;
    if (reactEl.type === TableFooter) {
      footer = reactEl.props.children;
      continue;
    }
    rows.push(reactEl);
  }
  var emptyRow = emptyState ? /*#__PURE__*/React.createElement(StyledTableRow, {
    className: "empty-state"
  }, /*#__PURE__*/React.createElement(StyledTableCell, {
    colSpan: headings.length
  }, emptyState)) : null;
  var hasRows = rows.length > 0;
  var rowsMarkup = hasRows ? rows : emptyRow;
  var showFooter = !!footer;
  var LoadingRow = function LoadingRow() {
    return /*#__PURE__*/React.createElement(StyledTableLoadingRow, {
      className: "loader-container"
    }, /*#__PURE__*/React.createElement(StyledLoaderWrapper, null, /*#__PURE__*/React.createElement(StyledSpinnerContainer, null, /*#__PURE__*/React.createElement(Spinner, null), /*#__PURE__*/React.createElement(Typography, {
      variant: "subtitle1"
    }, loadingLabel))));
  };
  return /*#__PURE__*/React.createElement(StyledDataTableContainer, {
    className: "data-table-container"
  }, /*#__PURE__*/React.createElement(StyledTable, _extends({
    ref: ref,
    "data-loading": loading,
    "data-has-footer": showFooter
  }, props), /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement(StyledTableRow, {
    "data-header": true
  }, rowHeaderMarkup)), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement(LoadingRow, null), totalsRowMarkup && hasRows && /*#__PURE__*/React.createElement(StyledTableRow, null, totalsRowMarkup), rowsMarkup), showFooter && /*#__PURE__*/React.createElement("tfoot", null, /*#__PURE__*/React.createElement(StyledTableFooterRow, null, /*#__PURE__*/React.createElement(StyledTableCell, {
    colSpan: headings.length
  }, footer)))));
});
export var DataTable = Object.assign(DataTableComponent, {
  Row: TableRow,
  Cell: TableCell,
  Footer: TableFooter
});