import React from 'react';
import nextId from 'react-id-generator';
import { Typography } from '../Typography';
import { Neutral } from '../utilities/colors';
import { StyledMenu, StyledSections, TitleContainer } from './MenuStyle';
import { MenuOptionLabel } from './components/MenuOptionLabel';
import { MenuOption } from './components/MenuOption';
import { MenuOptionCheckbox } from './components/MenuOptionCheckbox';
export var Menu = function Menu(_ref) {
  var allowMultiple = _ref.allowMultiple,
    id = _ref.id,
    onClick = _ref.onClick,
    options = _ref.options,
    sections = _ref.sections,
    selectedValues = _ref.selectedValues,
    title = _ref.title;
  var randomId = nextId('glints-menu');
  var menuId = id ? id : randomId;
  var renderTitle = function renderTitle(_ref2) {
    var title = _ref2.title;
    return /*#__PURE__*/React.createElement(TitleContainer, null, /*#__PURE__*/React.createElement(Typography, {
      variant: "subtitle2",
      as: "span",
      color: Neutral.B40
    }, title));
  };
  var renderOptions = function renderOptions(_ref3) {
    var options = _ref3.options;
    return /*#__PURE__*/React.createElement(StyledMenu, null, options == null ? void 0 : options.map(function (option) {
      var value = option.value,
        label = option.label,
        sublabel = option.sublabel,
        disabled = option.disabled,
        id = option.id;
      var randomId = nextId('glints-menu-option');
      var menuOptionId = id ? id : randomId;
      var isSelected = selectedValues == null ? void 0 : selectedValues.includes(value);
      return /*#__PURE__*/React.createElement(MenuOption, {
        key: menuOptionId,
        value: value,
        disabled: disabled,
        isSelected: isSelected,
        onClick: onClick,
        allowMultiple: allowMultiple
      }, /*#__PURE__*/React.createElement(MenuOptionLabel, {
        label: label,
        sublabel: sublabel
      }));
    }));
  };
  var renderOptionsWithCheckbox = function renderOptionsWithCheckbox(_ref4) {
    var options = _ref4.options;
    return /*#__PURE__*/React.createElement(StyledMenu, null, options == null ? void 0 : options.map(function (option) {
      var value = option.value,
        label = option.label,
        disabled = option.disabled,
        id = option.id;
      var randomId = nextId('glints-menu-option');
      var menuOptionId = id ? id : randomId;
      var isSelected = selectedValues == null ? void 0 : selectedValues.includes(value);
      return /*#__PURE__*/React.createElement(MenuOption, {
        key: menuOptionId,
        value: value,
        disabled: disabled,
        isSelected: isSelected,
        onClick: onClick,
        allowMultiple: allowMultiple
      }, /*#__PURE__*/React.createElement(MenuOptionCheckbox, {
        isSelected: isSelected,
        disabled: disabled,
        label: label
      }));
    }));
  };
  var renderSections = function renderSections(_ref5) {
    var sections = _ref5.sections;
    return /*#__PURE__*/React.createElement(StyledSections, null, sections.map(function (section, index) {
      return /*#__PURE__*/React.createElement("li", {
        key: "menu-section-" + title + "-" + index
      }, renderTitle({
        title: section == null ? void 0 : section.title
      }), allowMultiple ? renderOptionsWithCheckbox({
        options: section == null ? void 0 : section.options
      }) : renderOptions({
        options: section == null ? void 0 : section.options
      }));
    }));
  };
  return /*#__PURE__*/React.createElement("div", {
    id: menuId
  }, title && renderTitle({
    title: title
  }), allowMultiple ? renderOptionsWithCheckbox({
    options: options
  }) : renderOptions({
    options: options
  }), sections && renderSections({
    sections: sections
  }));
};