import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["isOpen", "header", "headerDescription", "children", "secondaryAction", "primaryAction", "customActions", "showBackButton", "showCloseButton", "showHeaderBorder", "headerHasDefaultPadding", "closeOnClickOutside", "onClose", "onBack", "zIndexOverride", "leftComponent", "rightComponent"];
import React, { useEffect, useRef, useState } from 'react';
import { Button, PrimaryButton } from '../Button';
import { ButtonGroup } from '../ButtonGroup';
import { Icon } from '../Icon';
import { Portal } from '../Portal/Portal';
import { Typography } from '../Typography';
import { StyledModalWrapper, StyledModalContainer, StyledModalHeader, StyledModalContent, StyledModalActions, StyledButtonContainer, StyledModalCloseButton, StyledModalBackButton, StyledModalLeftAndRightComponent } from './ModalStyle';
export var Modal = /*#__PURE__*/React.forwardRef(function Modal(_ref, ref) {
  var isOpen = _ref.isOpen,
    header = _ref.header,
    headerDescription = _ref.headerDescription,
    children = _ref.children,
    secondaryAction = _ref.secondaryAction,
    primaryAction = _ref.primaryAction,
    customActions = _ref.customActions,
    showBackButton = _ref.showBackButton,
    _ref$showCloseButton = _ref.showCloseButton,
    showCloseButton = _ref$showCloseButton === void 0 ? true : _ref$showCloseButton,
    _ref$showHeaderBorder = _ref.showHeaderBorder,
    showHeaderBorder = _ref$showHeaderBorder === void 0 ? true : _ref$showHeaderBorder,
    _ref$headerHasDefault = _ref.headerHasDefaultPadding,
    headerHasDefaultPadding = _ref$headerHasDefault === void 0 ? true : _ref$headerHasDefault,
    closeOnClickOutside = _ref.closeOnClickOutside,
    onClose = _ref.onClose,
    onBack = _ref.onBack,
    _ref$zIndexOverride = _ref.zIndexOverride,
    zIndexOverride = _ref$zIndexOverride === void 0 ? 999 : _ref$zIndexOverride,
    leftComponent = _ref.leftComponent,
    rightComponent = _ref.rightComponent,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var _useState = useState(false),
    isContentHasScrollbar = _useState[0],
    setIsContentHasScrollbar = _useState[1];
  var modalContentRef = useRef(null);
  useEffect(function () {
    var checkScrollbar = function checkScrollbar() {
      var modalContent = modalContentRef.current;
      if (modalContent) {
        setIsContentHasScrollbar(modalContent.scrollHeight > modalContent.clientHeight);
      }
    };
    checkScrollbar();
    var handleResize = function handleResize() {
      return checkScrollbar();
    };
    window.addEventListener('resize', handleResize);
    return function () {
      window.removeEventListener('resize', handleResize);
    };
  });
  useEffect(function () {
    if (typeof window === 'undefined' || !window.document) return;
    var enableScroll = function enableScroll() {
      document.body.style.overflow = 'unset';
    };
    if (isOpen) {
      document.body.style.overflow = 'hidden';
    } else {
      enableScroll();
    }
    return function () {
      enableScroll();
    };
  }, [isOpen]);
  if (!isOpen) {
    return null;
  }
  var defaultActionContent = /*#__PURE__*/React.createElement(ButtonGroup, null, secondaryAction && /*#__PURE__*/React.createElement(Button, _extends({
    onClick: function onClick() {
      return secondaryAction.action == null ? void 0 : secondaryAction.action();
    }
  }, secondaryAction), secondaryAction.label), primaryAction && /*#__PURE__*/React.createElement(PrimaryButton, _extends({
    onClick: function onClick() {
      return primaryAction.action == null ? void 0 : primaryAction.action();
    }
  }, primaryAction), primaryAction.label));
  var actionsContent = customActions ? customActions : defaultActionContent;
  var hasActions = !!customActions || !!primaryAction || !!secondaryAction;
  var content = typeof children === 'string' ? /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "body1"
  }, children) : children;
  var handleClickOutside = function handleClickOutside(event) {
    if (closeOnClickOutside) {
      onClose == null ? void 0 : onClose(event);
    }
  };
  return /*#__PURE__*/React.createElement(Portal, null, /*#__PURE__*/React.createElement(StyledModalWrapper, {
    "data-testid": "modal-wrapper",
    onClick: handleClickOutside,
    zIndexOverride: zIndexOverride
  }, leftComponent && /*#__PURE__*/React.createElement(StyledModalLeftAndRightComponent, {
    className: "modal-left-component"
  }, leftComponent), /*#__PURE__*/React.createElement(StyledModalContainer, _extends({
    ref: ref,
    onClick: function onClick(e) {
      return e.stopPropagation();
    }
  }, props), header && /*#__PURE__*/React.createElement(StyledModalHeader, {
    "data-show-border": showHeaderBorder,
    "data-header-has-default-padding": headerHasDefaultPadding
  }, showBackButton && /*#__PURE__*/React.createElement(StyledButtonContainer, null, /*#__PURE__*/React.createElement(StyledModalBackButton, {
    "data-testid": "modal-back-btn",
    "data-has-decription": !!headerDescription,
    onClick: function onClick() {
      return onBack == null ? void 0 : onBack();
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-arrow-left-line"
  }))), /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "subtitle1"
  }, header, /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "body1"
  }, headerDescription)), showCloseButton && /*#__PURE__*/React.createElement(StyledButtonContainer, null, /*#__PURE__*/React.createElement(StyledModalCloseButton, {
    "data-testid": "modal-close-btn",
    "data-has-decription": !!headerDescription,
    onClick: onClose
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-close"
  })))), /*#__PURE__*/React.createElement(StyledModalContent, {
    className: "modal-content",
    ref: modalContentRef,
    "data-has-scrollbar": isContentHasScrollbar
  }, content), hasActions && /*#__PURE__*/React.createElement(StyledModalActions, null, actionsContent)), rightComponent && /*#__PURE__*/React.createElement(StyledModalLeftAndRightComponent, {
    className: "modal-right-component"
  }, rightComponent)));
});