import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["isOpen", "title", "description", "showHorizontalLine", "children", "basicButtonAction", "primaryButtonAction", "showBackButton", "onBack", "showCloseButton", "onClose"];
import React, { useEffect, useState, useRef } from 'react';
import { Button, PrimaryButton } from '../Button';
import { ButtonGroup } from '../ButtonGroup';
import { Icon } from '../Icon';
import { Neutral } from '../utilities/colors';
import { Portal } from '../Portal/Portal';
import { StyledSideSheetContainer, StyledSideSheetWrapper, StyledSideSheetHeader, StyledButtonContainer, StyledRightContainer, StyledHorizontalLine, StyledSideSheetFooter, StyledButtonGroupContainer, SideSheetContent } from './SideSheetStyle';
import { Typography } from '../Typography';
import classNames from 'classnames';
var SideSheet = /*#__PURE__*/React.forwardRef(function SideSheet(_ref, ref) {
  var isOpen = _ref.isOpen,
    title = _ref.title,
    description = _ref.description,
    _ref$showHorizontalLi = _ref.showHorizontalLine,
    showHorizontalLine = _ref$showHorizontalLi === void 0 ? true : _ref$showHorizontalLi,
    children = _ref.children,
    basicButtonAction = _ref.basicButtonAction,
    primaryButtonAction = _ref.primaryButtonAction,
    _ref$showBackButton = _ref.showBackButton,
    showBackButton = _ref$showBackButton === void 0 ? true : _ref$showBackButton,
    onBack = _ref.onBack,
    _ref$showCloseButton = _ref.showCloseButton,
    showCloseButton = _ref$showCloseButton === void 0 ? true : _ref$showCloseButton,
    onClose = _ref.onClose,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  useEffect(function () {
    if (typeof window === 'undefined' || !window.document) return;
    var enableScroll = function enableScroll() {
      return document.body.style.overflow = 'unset';
    };
    isOpen ? document.body.style.overflow = 'hidden' : enableScroll();
    return function () {
      enableScroll();
    };
  }, [isOpen]);

  // store state for closing animation, and cleanup when unmounting
  var _useState = useState(false),
    isClosedAnimation = _useState[0],
    setIsClosedAnimation = _useState[1];
  var timeoutId = useRef(null);
  useEffect(function () {
    return function () {
      if (timeoutId.current) {
        clearTimeout(timeoutId.current);
      }
    };
  }, []);

  // fade out effect for 0.2seconds when closed
  var handleClose = function handleClose() {
    setIsClosedAnimation(true);
    timeoutId.current = setTimeout(function () {
      setIsClosedAnimation(false);
      onClose();
    }, 190); // purposefully made this 0.19sec (to prevent rare animation glitch)
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, isOpen && /*#__PURE__*/React.createElement(Portal, null, /*#__PURE__*/React.createElement(StyledSideSheetWrapper, {
    className: "side-sheet-wrapper " + (isClosedAnimation ? 'closed' : ''),
    onClick: handleClose
  }, /*#__PURE__*/React.createElement(StyledSideSheetContainer, _extends({
    className: classNames({
      closed: isClosedAnimation
    }, 'side-sheet-container'),
    ref: ref,
    onClick: function onClick(e) {
      return e.stopPropagation();
    }
  }, props), /*#__PURE__*/React.createElement(StyledSideSheetHeader, null, showBackButton && /*#__PURE__*/React.createElement(StyledButtonContainer, {
    onClick: onBack
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-arrow-left-line"
  })), /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "subtitle1",
    style: {
      color: Neutral.B18
    }
  }, title, /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "body1",
    style: {
      color: Neutral.B18
    }
  }, description)), showCloseButton && /*#__PURE__*/React.createElement(StyledRightContainer, null, /*#__PURE__*/React.createElement(StyledButtonContainer, {
    "data-testid": "sidesheet-close-btn",
    onClick: handleClose
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-close"
  })))), showHorizontalLine && /*#__PURE__*/React.createElement(StyledHorizontalLine, null), /*#__PURE__*/React.createElement(SideSheetContent, {
    className: "sidesheet-content"
  }, children), (basicButtonAction || primaryButtonAction) && /*#__PURE__*/React.createElement(StyledSideSheetFooter, null, /*#__PURE__*/React.createElement(StyledHorizontalLine, null), /*#__PURE__*/React.createElement(StyledButtonGroupContainer, null, /*#__PURE__*/React.createElement(ButtonGroup, {
    fullWidth: true
  }, basicButtonAction && /*#__PURE__*/React.createElement(Button, _extends({}, basicButtonAction, {
    onClick: basicButtonAction.action,
    fullWidth: true
  }), basicButtonAction.label), primaryButtonAction && /*#__PURE__*/React.createElement(PrimaryButton, _extends({}, primaryButtonAction, {
    onClick: primaryButtonAction.action
  }), primaryButtonAction.label))))))));
});
export { SideSheet };