import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["value", "rows", "maxLength", "error", "disabled", "width", "onChange", "forwardedRef", "canExceedMaxLength", "required", "border", "borderRadius", "isPlaceholderFloating", "floatingFontSize", "placeholder", "floatingPlaceholderTop", "placeholderColor"];
import React, { useRef, useState } from 'react';
import { StyledTextAreaContainer, StyledTextArea, StyledWordCountContainer } from './TextAreaStyle';
import { Typography } from '../Typography';
import { AsteriskIcon, FloatingLabel } from '../Input/InputStyle';
var _TextArea = function _TextArea(_ref) {
  var value = _ref.value,
    _ref$rows = _ref.rows,
    rows = _ref$rows === void 0 ? 3 : _ref$rows,
    maxLength = _ref.maxLength,
    _ref$error = _ref.error,
    error = _ref$error === void 0 ? false : _ref$error,
    _ref$disabled = _ref.disabled,
    disabled = _ref$disabled === void 0 ? false : _ref$disabled,
    _ref$width = _ref.width,
    width = _ref$width === void 0 ? '520px' : _ref$width,
    onChange = _ref.onChange,
    forwardedRef = _ref.forwardedRef,
    _ref$canExceedMaxLeng = _ref.canExceedMaxLength,
    canExceedMaxLength = _ref$canExceedMaxLeng === void 0 ? true : _ref$canExceedMaxLeng,
    required = _ref.required,
    border = _ref.border,
    borderRadius = _ref.borderRadius,
    isPlaceholderFloating = _ref.isPlaceholderFloating,
    floatingFontSize = _ref.floatingFontSize,
    placeholder = _ref.placeholder,
    floatingPlaceholderTop = _ref.floatingPlaceholderTop,
    placeholderColor = _ref.placeholderColor,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var _useState = useState(false),
    isFocused = _useState[0],
    setIsFocused = _useState[1];
  var charCount = value.length;
  var hasMaxLengthEnforced = maxLength > 0;
  var hasError = error || canExceedMaxLength && charCount > maxLength;
  var localRef = useRef(null);
  var textAreaInputRef = forwardedRef || localRef;
  var handleContainerClick = function handleContainerClick() {
    if (textAreaInputRef.current) {
      textAreaInputRef.current.focus();
    }
  };
  var handleChange = function handleChange(e) {
    var val = e.currentTarget.value;
    onChange(val);
  };
  return /*#__PURE__*/React.createElement(StyledTextAreaContainer, {
    "data-error": hasError,
    "data-disabled": disabled,
    "data-focus": isFocused,
    "data-has-counter": hasMaxLengthEnforced,
    width: width,
    onClick: handleContainerClick,
    border: border,
    borderRadius: borderRadius,
    isPlaceholderFloating: isPlaceholderFloating
  }, /*#__PURE__*/React.createElement(StyledTextArea, _extends({
    ref: textAreaInputRef,
    value: value,
    rows: rows,
    width: width,
    onChange: handleChange,
    disabled: disabled,
    maxLength: !canExceedMaxLength && maxLength,
    onFocus: function onFocus() {
      return setIsFocused(true);
    },
    onBlur: function onBlur() {
      return setIsFocused(false);
    },
    border: border,
    borderRadius: borderRadius,
    placeholder: isPlaceholderFloating && !disabled ? undefined : placeholder
  }, props)), hasMaxLengthEnforced && /*#__PURE__*/React.createElement(StyledWordCountContainer, {
    "data-disabled": disabled,
    "data-error": hasError
  }, /*#__PURE__*/React.createElement(Typography, {
    as: "span",
    variant: "overline"
  }, charCount, " / ", maxLength)), isPlaceholderFloating && !disabled && /*#__PURE__*/React.createElement(FloatingLabel, {
    "data-testid": "textarea-label",
    "data-error": error,
    fontSize: floatingFontSize,
    color: placeholderColor,
    top: floatingPlaceholderTop
  }, placeholder, required && /*#__PURE__*/React.createElement(AsteriskIcon, null, "*")));
};
var forwardRef = function forwardRef(props, ref) {
  return /*#__PURE__*/React.createElement(_TextArea, _extends({}, props, {
    forwardedRef: ref
  }));
};
forwardRef.displayName = _TextArea.name;
export var TextArea = /*#__PURE__*/React.forwardRef(forwardRef);