import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["children", "content", "preferredPosition", "zIndex", "clickable", "timeout", "onClick", "tooltipClassName"];
import React, { useEffect, useRef, useState } from 'react';
import { Portal } from '../Portal/Portal';
import { Typography } from '../Typography';
import { bottomPositionResolver, leftPositionResolver, rightPositionResolver, topPositionResolver } from './positionResolver';
import { canAlignBottom, canAlignCenter, canAlignLeft, canAlignMiddle, canAlignRight, canAlignTop, horizontalBuffer, verticalBuffer } from './positionResolverHelper';
import { StyledTooltip, StyledTooltipArrow, StyledTooltipContainer } from './TooltipStyle';
import classNames from 'classnames';
var topPositions = ['top-center', 'top-left', 'top-right'];
var bottomPositions = ['bottom-center', 'bottom-left', 'bottom-right'];
var rightPositions = ['right-middle', 'right-top', 'right-bottom'];
var leftPositions = ['left-middle', 'left-top', 'left-bottom'];
var allPositions = [].concat(topPositions, bottomPositions, rightPositions, leftPositions);
var tooltipPositionResolvers = {
  'top-center': function topCenter(tooltipRect, elementRect) {
    return topPositionResolver(tooltipRect, elementRect, [canAlignCenter, canAlignLeft, canAlignRight]);
  },
  'top-left': function topLeft(tooltipRect, elementRect) {
    return topPositionResolver(tooltipRect, elementRect, [canAlignLeft, canAlignCenter, canAlignRight]);
  },
  'top-right': function topRight(tooltipRect, elementRect) {
    return topPositionResolver(tooltipRect, elementRect, [canAlignRight, canAlignCenter, canAlignLeft]);
  },
  'bottom-center': function bottomCenter(tooltipRect, elementRect) {
    return bottomPositionResolver(tooltipRect, elementRect, [canAlignCenter, canAlignLeft, canAlignRight]);
  },
  'bottom-left': function bottomLeft(tooltipRect, elementRect) {
    return bottomPositionResolver(tooltipRect, elementRect, [canAlignLeft, canAlignCenter, canAlignRight]);
  },
  'bottom-right': function bottomRight(tooltipRect, elementRect) {
    return bottomPositionResolver(tooltipRect, elementRect, [canAlignRight, canAlignCenter, canAlignLeft]);
  },
  'right-middle': function rightMiddle(tooltipRect, elementRect) {
    return rightPositionResolver(tooltipRect, elementRect, [canAlignMiddle, canAlignTop, canAlignBottom]);
  },
  'right-top': function rightTop(tooltipRect, elementRect) {
    return rightPositionResolver(tooltipRect, elementRect, [canAlignTop, canAlignMiddle, canAlignBottom]);
  },
  'right-bottom': function rightBottom(tooltipRect, elementRect) {
    return rightPositionResolver(tooltipRect, elementRect, [canAlignBottom, canAlignMiddle, canAlignTop]);
  },
  'left-middle': function leftMiddle(tooltipRect, elementRect) {
    return leftPositionResolver(tooltipRect, elementRect, [canAlignMiddle, canAlignTop, canAlignBottom]);
  },
  'left-top': function leftTop(tooltipRect, elementRect) {
    return leftPositionResolver(tooltipRect, elementRect, [canAlignTop, canAlignMiddle, canAlignBottom]);
  },
  'left-bottom': function leftBottom(tooltipRect, elementRect) {
    return leftPositionResolver(tooltipRect, elementRect, [canAlignBottom, canAlignMiddle, canAlignTop]);
  }
};
var defaultPosition = 'top-center';
export var Tooltip = function Tooltip(_ref) {
  var children = _ref.children,
    content = _ref.content,
    _ref$preferredPositio = _ref.preferredPosition,
    preferredPosition = _ref$preferredPositio === void 0 ? defaultPosition : _ref$preferredPositio,
    zIndex = _ref.zIndex,
    _ref$clickable = _ref.clickable,
    clickable = _ref$clickable === void 0 ? false : _ref$clickable,
    _ref$timeout = _ref.timeout,
    timeout = _ref$timeout === void 0 ? 0 : _ref$timeout,
    onClick = _ref.onClick,
    tooltipClassName = _ref.tooltipClassName,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var tooltipRef = useRef(null);
  var elRef = useRef(null);
  var tooltipPositionsHandlerRef = useRef(null);
  var _useState = useState(null),
    toolTipCoord = _useState[0],
    setToolTipCoord = _useState[1];
  var _useState2 = useState(false),
    isActive = _useState2[0],
    setIsActive = _useState2[1];
  var _useState3 = useState(null),
    overridePosition = _useState3[0],
    setOverridePosition = _useState3[1];
  if (!allPositions.includes(preferredPosition)) {
    preferredPosition = defaultPosition;
    console.warn("\"" + preferredPosition + "\" is not a valid tooltip positon, \"" + defaultPosition + "\" will be used instead");
  }
  var position = overridePosition || preferredPosition;
  var handleTooltipPositions = function handleTooltipPositions(tooltipRect, elRect, currentPosition) {
    var resolver = tooltipPositionResolvers[position] || tooltipPositionResolvers[defaultPosition];
    var newLeft = 0;
    var newTop = 0;
    if (position.startsWith('top')) {
      newTop = elRect.top - tooltipRect.height - verticalBuffer;
      newLeft = elRect.left + elRect.width / 2;
    }
    if (position.startsWith('bottom')) {
      newTop = elRect.top + elRect.height + verticalBuffer;
      newLeft = elRect.left + elRect.width / 2;
    }
    if (position.startsWith('left')) {
      newTop = elRect.top + elRect.height / 2;
      newLeft = elRect.left - tooltipRect.width - horizontalBuffer;
    }
    if (position.startsWith('right')) {
      newTop = elRect.top + elRect.height / 2;
      newLeft = elRect.left + elRect.width + horizontalBuffer;
    }
    setToolTipCoord({
      top: newTop,
      left: newLeft
    });
    var tooltipRectNew = new DOMRect(newLeft, newTop, tooltipRect.width, tooltipRect.height);
    var resolvedPosition = resolver(tooltipRectNew, elRect);
    if (!overridePosition && resolvedPosition !== currentPosition) {
      setOverridePosition(resolvedPosition);
    }
  };
  tooltipPositionsHandlerRef.current = handleTooltipPositions;
  useEffect(function () {
    if (isActive) {
      var _tooltipRef$current, _elRef$current;
      tooltipPositionsHandlerRef.current(tooltipRef == null ? void 0 : (_tooltipRef$current = tooltipRef.current) == null ? void 0 : _tooltipRef$current.getClientRects()[0], elRef == null ? void 0 : (_elRef$current = elRef.current) == null ? void 0 : _elRef$current.getClientRects()[0], position);
    }
  }, [isActive, position]);
  var contentMarkup = typeof content === 'string' ? /*#__PURE__*/React.createElement(Typography, {
    as: "div",
    variant: "subtitle2"
  }, content) : content;
  var handleMouseEnter = function handleMouseEnter() {
    if (!clickable) setIsActive(true);
  };
  var handleMouseLeave = function handleMouseLeave() {
    if (!clickable) {
      setIsActive(false);
      handleAnimation();
    }
  };
  var handleClick = function handleClick() {
    if (clickable) {
      onClick();
      handleAnimation();
    }
  };
  var timeoutRef = useRef(null);
  var _useState4 = useState(false),
    animate = _useState4[0],
    setAnimate = _useState4[1];
  var handleAnimation = function handleAnimation() {
    // if you click during the tooltip's lifespan, it should reset the timeout
    if (timeoutRef.current) {
      clearTimeout(timeoutRef.current);
      timeoutRef.current = null;
      setAnimate(false);
    }
    setIsActive(true);
    timeoutRef.current = setTimeout(function () {
      setAnimate(true);
      timeoutRef.current = setTimeout(function () {
        setIsActive(false);
        setAnimate(false);
      }, 370); // animation is 400ms, make this slightly lower to prevent visual glitch
    }, timeout);
  };
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(StyledTooltipContainer, _extends({
    ref: elRef,
    onMouseEnter: handleMouseEnter,
    onMouseLeave: handleMouseLeave,
    onClick: handleClick
  }, props), children), isActive && /*#__PURE__*/React.createElement(Portal, null, /*#__PURE__*/React.createElement(StyledTooltip, {
    "data-position": position,
    className: classNames({
      'closed-animation': animate
    }, tooltipClassName),
    ref: tooltipRef,
    zIndex: zIndex,
    style: {
      top: (toolTipCoord == null ? void 0 : toolTipCoord.top) + 'px',
      left: (toolTipCoord == null ? void 0 : toolTipCoord.left) + 'px',
      visibility: toolTipCoord ? 'visible' : 'hidden'
    }
  }, /*#__PURE__*/React.createElement(StyledTooltipArrow, {
    className: "arrow"
  }), contentMarkup)));
};