import { canAlignLeft, canAlignRight, canAlignCenter, canStayOnTop, canFitOnTheLeft, horizontalBuffer, canFitOnTheRight, canFitBelow, verticalBuffer, tryCalculateAligment, canAlignMiddle, canAlignTop, canAlignBottom, canStayOnBottom, canFitOnTheTop, canStayOnLeft, canStayOnRight } from './positionResolverHelper';
export var topPositionResolver = function topPositionResolver(tooltipRect, elRect, preferredAligmentFuncs) {
  var horizontalPreferredAligmentFuncs = preferredAligmentFuncs;
  var verticalPreferredAligmentFuncs = [canAlignMiddle, canAlignTop, canAlignBottom];
  if (canStayOnTop(tooltipRect)) {
    var alignResult = tryCalculateAligment({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (alignResult) {
      return "top-" + alignResult;
    }
  }
  if (canFitOnTheLeft(tooltipRect, elRect, horizontalBuffer)) {
    var _alignResult = tryCalculateAligment({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult) {
      return "left-" + _alignResult;
    }
  }
  if (canFitOnTheRight(tooltipRect, elRect, horizontalBuffer)) {
    var _alignResult2 = tryCalculateAligment({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult2) {
      return "right-" + _alignResult2;
    }
  }
  if (canFitBelow(tooltipRect, elRect, verticalBuffer)) {
    var _alignResult3 = tryCalculateAligment({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult3) {
      return "bottom-" + _alignResult3;
    }
  }
  return 'top-center';
};
export var bottomPositionResolver = function bottomPositionResolver(tooltipRect, elRect, preferredAligmentFuncs) {
  var horizontalPreferredAligmentFuncs = preferredAligmentFuncs;
  var verticalPreferredAligmentFuncs = [canAlignMiddle, canAlignTop, canAlignBottom];
  if (canStayOnBottom(tooltipRect)) {
    var alignResult = tryCalculateAligment({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (alignResult) {
      return "bottom-" + alignResult;
    }
  }
  if (canFitOnTheLeft(tooltipRect, elRect, horizontalBuffer)) {
    var _alignResult4 = tryCalculateAligment({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult4) {
      return "left-" + _alignResult4;
    }
  }
  if (canFitOnTheRight(tooltipRect, elRect, horizontalBuffer)) {
    var _alignResult5 = tryCalculateAligment({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult5) {
      return "right-" + _alignResult5;
    }
  }
  if (canFitOnTheTop(tooltipRect, elRect, verticalBuffer)) {
    var _alignResult6 = tryCalculateAligment({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult6) {
      return "top-" + _alignResult6;
    }
  }
  return 'bottom-center';
};
export var leftPositionResolver = function leftPositionResolver(tooltipRect, elRect, preferredAligmentFuncs) {
  var horizontalPreferredAligmentFuncs = [canAlignCenter, canAlignLeft, canAlignRight];
  var verticalPreferredAligmentFuncs = preferredAligmentFuncs;
  if (canStayOnLeft(tooltipRect)) {
    var alignResult = tryCalculateAligment({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (alignResult) {
      return "left-" + alignResult;
    }
  }
  if (canFitOnTheTop(tooltipRect, elRect, horizontalBuffer)) {
    var _alignResult7 = tryCalculateAligment({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult7) {
      return "top-" + _alignResult7;
    }
  }
  if (canFitOnTheRight(tooltipRect, elRect, horizontalBuffer)) {
    var _alignResult8 = tryCalculateAligment({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult8) {
      return "right-" + _alignResult8;
    }
  }
  if (canFitBelow(tooltipRect, elRect, verticalBuffer)) {
    var _alignResult9 = tryCalculateAligment({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult9) {
      return "bottom-" + _alignResult9;
    }
  }
  return 'left-middle';
};
export var rightPositionResolver = function rightPositionResolver(tooltipRect, elRect, preferredAligmentFuncs) {
  var horizontalPreferredAligmentFuncs = [canAlignCenter, canAlignLeft, canAlignRight];
  var verticalPreferredAligmentFuncs = preferredAligmentFuncs;
  if (canStayOnRight(tooltipRect)) {
    var alignResult = tryCalculateAligment({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (alignResult) {
      return "right-" + alignResult;
    }
  }
  if (canFitOnTheTop(tooltipRect, elRect, horizontalBuffer)) {
    var _alignResult10 = tryCalculateAligment({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult10) {
      return "top-" + _alignResult10;
    }
  }
  if (canFitOnTheLeft(tooltipRect, elRect, horizontalBuffer)) {
    var _alignResult11 = tryCalculateAligment({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult11) {
      return "left-" + _alignResult11;
    }
  }
  if (canFitBelow(tooltipRect, elRect, verticalBuffer)) {
    var _alignResult12 = tryCalculateAligment({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult12) {
      return "bottom-" + _alignResult12;
    }
  }
  return 'right-middle';
};