import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["file", "handleSetFile", "loading", "objectFit", "uploadMessage", "loadingMessage", "disableDefaultValidation", "accept"];
import React, { useEffect, useRef, useState } from 'react';
import { Icon } from '../Icon';
import { StyledInvisibleInput, StyledUploadContainer, StyledTextContainer, StyledIconContainer, StyledUploadedImage, StyledDeleteButtonContainer, StyledDeleteIconContainer, StyledErrorContainer, StyledErrorIconContainer, StyledErrorTextContainer } from './UploadStyle';
import { Spinner } from '../Spinner';
import { Typography } from '../Typography';
export var Upload = /*#__PURE__*/React.forwardRef(function Upload(_ref, ref) {
  var file = _ref.file,
    handleSetFile = _ref.handleSetFile,
    loading = _ref.loading,
    _ref$objectFit = _ref.objectFit,
    objectFit = _ref$objectFit === void 0 ? 'cover' : _ref$objectFit,
    _ref$uploadMessage = _ref.uploadMessage,
    uploadMessage = _ref$uploadMessage === void 0 ? 'Upload' : _ref$uploadMessage,
    _ref$loadingMessage = _ref.loadingMessage,
    loadingMessage = _ref$loadingMessage === void 0 ? 'loading...' : _ref$loadingMessage,
    _ref$disableDefaultVa = _ref.disableDefaultValidation,
    disableDefaultValidation = _ref$disableDefaultVa === void 0 ? false : _ref$disableDefaultVa,
    accept = _ref.accept,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var MAX_FILE_SIZE = 5; // in MB

  var _useState = useState(''),
    attachmentUrl = _useState[0],
    setAttachmentUrl = _useState[1];
  var _useState2 = useState(loading),
    isLoading = _useState2[0],
    setIsLoading = _useState2[1];
  var _useState3 = useState(''),
    error = _useState3[0],
    setError = _useState3[1];
  var fileInputRef = useRef(null);
  useEffect(function () {
    var reader = new FileReader();
    reader.onloadend = function () {
      setAttachmentUrl(reader.result);
      setIsLoading(false);
    };
    reader.onloadstart = function () {
      return setIsLoading(true);
    };
    if (file) reader.readAsDataURL(file);
  }, [file, loading]);
  var handleClick = function handleClick() {
    if (fileInputRef.current) {
      fileInputRef.current.click();
    }
  };
  var handleChange = function handleChange(event) {
    var _event$target$files;
    var newFile = (_event$target$files = event.target.files) == null ? void 0 : _event$target$files[0];
    if (disableDefaultValidation) {
      var _event$target$files2;
      handleSetFile(((_event$target$files2 = event.target.files) == null ? void 0 : _event$target$files2[0]) || null);
      return;
    }
    if (newFile && !newFile.type.startsWith('image')) {
      setError('Image required');
      handleSetFile(null);
    } else if (newFile && newFile.size > MAX_FILE_SIZE * 1024 * 1024) {
      setError('File too big');
      handleSetFile(null);
    } else {
      setError('');
      handleSetFile(newFile);
    }
  };
  var handleDelete = function handleDelete() {
    setAttachmentUrl('');
    handleSetFile(null);
    fileInputRef.current.value = null;
  };
  var unuploadedComponent = /*#__PURE__*/React.createElement(StyledUploadContainer, {
    onClick: handleClick,
    "data-type": "initial",
    "data-error": !!error,
    "data-testid": "upload-container"
  }, /*#__PURE__*/React.createElement(StyledIconContainer, null, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-add"
  })), /*#__PURE__*/React.createElement(StyledTextContainer, null, /*#__PURE__*/React.createElement(Typography, {
    as: "span",
    variant: "button"
  }, uploadMessage)));
  var loadingComponent = /*#__PURE__*/React.createElement(StyledUploadContainer, {
    "data-type": "loading"
  }, /*#__PURE__*/React.createElement(StyledIconContainer, {
    "data-type": "loading"
  }, /*#__PURE__*/React.createElement(Spinner, null)), /*#__PURE__*/React.createElement(StyledTextContainer, null, /*#__PURE__*/React.createElement(Typography, {
    as: "span",
    variant: "overline"
  }, loadingMessage)));
  var errorComponent = /*#__PURE__*/React.createElement(StyledErrorContainer, null, /*#__PURE__*/React.createElement(StyledErrorIconContainer, null, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-error-warning-fill"
  })), /*#__PURE__*/React.createElement(StyledErrorTextContainer, null, /*#__PURE__*/React.createElement(Typography, {
    as: "span",
    variant: "subtitle2"
  }, error)));
  var uploadedImageComponent = /*#__PURE__*/React.createElement(StyledUploadedImage, {
    src: attachmentUrl,
    objectFit: objectFit
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(StyledInvisibleInput, _extends({
    type: "file",
    accept: accept || 'image/*',
    onChange: handleChange,
    ref: ref || fileInputRef
  }, props)), attachmentUrl && !(loading || isLoading) ? /*#__PURE__*/React.createElement(StyledUploadContainer, {
    "data-type": "image",
    "data-testid": "upload-container"
  }, uploadedImageComponent, /*#__PURE__*/React.createElement(StyledDeleteButtonContainer, {
    onClick: handleDelete
  }, /*#__PURE__*/React.createElement(StyledDeleteIconContainer, null, /*#__PURE__*/React.createElement(Icon, {
    name: "ri-delete-bin-line"
  })))) : /*#__PURE__*/React.createElement(React.Fragment, null, loading || isLoading ? /*#__PURE__*/React.createElement(React.Fragment, null, loadingComponent) : /*#__PURE__*/React.createElement(React.Fragment, null, unuploadedComponent), !!error && /*#__PURE__*/React.createElement(React.Fragment, null, errorComponent)));
});