"use strict";

exports.__esModule = true;
exports.useWindowSize = void 0;
var _react = require("react");
// Hook
var useWindowSize = function useWindowSize() {
  // Initialize state with undefined width/height so server and client renders match
  // Learn more here: https://joshwcomeau.com/react/the-perils-of-rehydration/
  var _useState = (0, _react.useState)({
      width: undefined,
      height: undefined
    }),
    windowSize = _useState[0],
    setWindowSize = _useState[1];
  (0, _react.useEffect)(function () {
    // Handler to call on window resize
    function handleResize() {
      // Set window width/height to state
      setWindowSize({
        width: window.innerWidth,
        height: window.innerHeight
      });
    }

    // Add event listener
    window.addEventListener('resize', handleResize);

    // Call handler right away so state gets updated with initial window size
    handleResize();

    // Remove event listener on cleanup
    return function () {
      return window.removeEventListener('resize', handleResize);
    };
  }, []); // Empty array ensures that effect is only run on mount

  return windowSize;
};

// Taken from https://usehooks.com/useWindowSize/
exports.useWindowSize = useWindowSize;