"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.Checkbox = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));
var _react = _interopRequireWildcard(require("react"));
var _CheckboxStyle = require("./CheckboxStyle");
var _lodash = require("lodash");
var _Icon = require("../Icon");
var _Typography = require("../Typography");
var _reactIdGenerator = _interopRequireDefault(require("react-id-generator"));
var _excluded = ["label", "id", "checked", "onChange", "disabled", "indeterminate", "hasError", "helpText", "isPadded", "isControlled"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var Checkbox = /*#__PURE__*/_react["default"].forwardRef(function Checkbox(_ref, ref) {
  var label = _ref.label,
    id = _ref.id,
    checked = _ref.checked,
    onChange = _ref.onChange,
    disabled = _ref.disabled,
    indeterminate = _ref.indeterminate,
    hasError = _ref.hasError,
    helpText = _ref.helpText,
    _ref$isPadded = _ref.isPadded,
    isPadded = _ref$isPadded === void 0 ? true : _ref$isPadded,
    _ref$isControlled = _ref.isControlled,
    isControlled = _ref$isControlled === void 0 ? false : _ref$isControlled,
    otherProps = (0, _objectWithoutPropertiesLoose2["default"])(_ref, _excluded);
  var randomId = (0, _reactIdGenerator["default"])('glints-checkbox');
  var checkBoxId = id ? id : randomId;
  var labelId = "label-" + checkBoxId;
  var inputNode = (0, _react.useRef)(null);
  var _useState = (0, _react.useState)(false),
    checkedState = _useState[0],
    setCheckedState = _useState[1];
  var _useState2 = (0, _react.useState)(false),
    isFocused = _useState2[0],
    setIsFocused = _useState2[1];
  var checkedIcon = indeterminate ? 'ri-checkbox-indeterminate-fill' : 'ri-checkbox-fill';
  (0, _react.useEffect)(function () {
    var value = indeterminate ? 'mixed' : checked;
    setCheckedState(value);
  }, [checked, indeterminate]);
  var handleClick = function handleClick() {
    if (!inputNode.current || disabled) {
      return;
    }
    var checkedValue = !checkedState;
    setCheckedState(checkedValue);
    onChange == null ? void 0 : onChange(checkedValue, checkBoxId);
  };
  return /*#__PURE__*/_react["default"].createElement(_CheckboxStyle.StyledContainer, {
    ref: ref,
    "aria-disabled": disabled,
    "data-error": hasError,
    "data-spacing": isPadded
  }, /*#__PURE__*/_react["default"].createElement(_CheckboxStyle.StyledRow, {
    className: "glints-checkbox-styled-row"
  }, /*#__PURE__*/_react["default"].createElement(_CheckboxStyle.StyledLeftColumn, null, /*#__PURE__*/_react["default"].createElement(_CheckboxStyle.StyledCheckboxContainer, null, /*#__PURE__*/_react["default"].createElement(_CheckboxStyle.StyledCheckbox, {
    role: "checkbox",
    "aria-labelledby": labelId,
    "aria-checked": isControlled ? checked : checkedState,
    "data-focus": isFocused,
    onClick: function onClick() {
      return handleClick();
    },
    onMouseDown: function onMouseDown() {
      return setIsFocused(false);
    },
    onMouseUp: function onMouseUp() {
      return setIsFocused(false);
    },
    hasError: hasError
  }, /*#__PURE__*/_react["default"].createElement("input", (0, _extends2["default"])({
    ref: inputNode,
    disabled: disabled,
    id: checkBoxId,
    type: "checkbox",
    onChange: _lodash.noop,
    checked: checked,
    onFocus: function onFocus() {
      return setIsFocused(true);
    },
    onBlur: function onBlur() {
      return setIsFocused(false);
    }
  }, otherProps))), /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    name: checkedIcon
  }))), /*#__PURE__*/_react["default"].createElement(_CheckboxStyle.StyledColumn, null, /*#__PURE__*/_react["default"].createElement("label", {
    id: labelId,
    htmlFor: checkBoxId,
    onClick: function onClick(e) {
      e.preventDefault();
      handleClick();
    },
    onMouseDown: function onMouseDown(e) {
      return e.preventDefault();
    },
    onMouseUp: function onMouseUp(e) {
      return e.preventDefault();
    }
  }, /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "div",
    variant: "body1"
  }, label)))), helpText && /*#__PURE__*/_react["default"].createElement(_CheckboxStyle.StyledRow, null, /*#__PURE__*/_react["default"].createElement(_CheckboxStyle.StyledLeftColumn, null), /*#__PURE__*/_react["default"].createElement(_CheckboxStyle.StyledColumn, {
    className: "help-text"
  }, /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "span",
    variant: "subtitle2"
  }, helpText))));
});
exports.Checkbox = Checkbox;