"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.Menu = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactIdGenerator = _interopRequireDefault(require("react-id-generator"));
var _Typography = require("../Typography");
var _colors = require("../utilities/colors");
var _MenuStyle = require("./MenuStyle");
var _MenuOptionLabel = require("./components/MenuOptionLabel");
var _MenuOption = require("./components/MenuOption");
var _MenuOptionCheckbox = require("./components/MenuOptionCheckbox");
var Menu = function Menu(_ref) {
  var allowMultiple = _ref.allowMultiple,
    id = _ref.id,
    onClick = _ref.onClick,
    options = _ref.options,
    sections = _ref.sections,
    selectedValues = _ref.selectedValues,
    title = _ref.title;
  var randomId = (0, _reactIdGenerator["default"])('glints-menu');
  var menuId = id ? id : randomId;
  var renderTitle = function renderTitle(_ref2) {
    var title = _ref2.title;
    return /*#__PURE__*/_react["default"].createElement(_MenuStyle.TitleContainer, null, /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
      variant: "subtitle2",
      as: "span",
      color: _colors.Neutral.B40
    }, title));
  };
  var renderOptions = function renderOptions(_ref3) {
    var options = _ref3.options;
    return /*#__PURE__*/_react["default"].createElement(_MenuStyle.StyledMenu, null, options == null ? void 0 : options.map(function (option) {
      var value = option.value,
        label = option.label,
        sublabel = option.sublabel,
        disabled = option.disabled,
        id = option.id;
      var randomId = (0, _reactIdGenerator["default"])('glints-menu-option');
      var menuOptionId = id ? id : randomId;
      var isSelected = selectedValues == null ? void 0 : selectedValues.includes(value);
      return /*#__PURE__*/_react["default"].createElement(_MenuOption.MenuOption, {
        key: menuOptionId,
        value: value,
        disabled: disabled,
        isSelected: isSelected,
        onClick: onClick,
        allowMultiple: allowMultiple
      }, /*#__PURE__*/_react["default"].createElement(_MenuOptionLabel.MenuOptionLabel, {
        label: label,
        sublabel: sublabel
      }));
    }));
  };
  var renderOptionsWithCheckbox = function renderOptionsWithCheckbox(_ref4) {
    var options = _ref4.options;
    return /*#__PURE__*/_react["default"].createElement(_MenuStyle.StyledMenu, null, options == null ? void 0 : options.map(function (option) {
      var value = option.value,
        label = option.label,
        disabled = option.disabled,
        id = option.id;
      var randomId = (0, _reactIdGenerator["default"])('glints-menu-option');
      var menuOptionId = id ? id : randomId;
      var isSelected = selectedValues == null ? void 0 : selectedValues.includes(value);
      return /*#__PURE__*/_react["default"].createElement(_MenuOption.MenuOption, {
        key: menuOptionId,
        value: value,
        disabled: disabled,
        isSelected: isSelected,
        onClick: onClick,
        allowMultiple: allowMultiple
      }, /*#__PURE__*/_react["default"].createElement(_MenuOptionCheckbox.MenuOptionCheckbox, {
        isSelected: isSelected,
        disabled: disabled,
        label: label
      }));
    }));
  };
  var renderSections = function renderSections(_ref5) {
    var sections = _ref5.sections;
    return /*#__PURE__*/_react["default"].createElement(_MenuStyle.StyledSections, null, sections.map(function (section, index) {
      return /*#__PURE__*/_react["default"].createElement("li", {
        key: "menu-section-" + title + "-" + index
      }, renderTitle({
        title: section == null ? void 0 : section.title
      }), allowMultiple ? renderOptionsWithCheckbox({
        options: section == null ? void 0 : section.options
      }) : renderOptions({
        options: section == null ? void 0 : section.options
      }));
    }));
  };
  return /*#__PURE__*/_react["default"].createElement("div", {
    id: menuId
  }, title && renderTitle({
    title: title
  }), allowMultiple ? renderOptionsWithCheckbox({
    options: options
  }) : renderOptions({
    options: options
  }), sections && renderSections({
    sections: sections
  }));
};
exports.Menu = Menu;