"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.Modal = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));
var _react = _interopRequireWildcard(require("react"));
var _Button = require("../Button");
var _ButtonGroup = require("../ButtonGroup");
var _Icon = require("../Icon");
var _Portal = require("../Portal/Portal");
var _Typography = require("../Typography");
var _ModalStyle = require("./ModalStyle");
var _excluded = ["isOpen", "header", "headerDescription", "children", "secondaryAction", "primaryAction", "customActions", "showBackButton", "showCloseButton", "showHeaderBorder", "headerHasDefaultPadding", "closeOnClickOutside", "onClose", "onBack", "zIndexOverride", "leftComponent", "rightComponent"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var Modal = /*#__PURE__*/_react["default"].forwardRef(function Modal(_ref, ref) {
  var isOpen = _ref.isOpen,
    header = _ref.header,
    headerDescription = _ref.headerDescription,
    children = _ref.children,
    secondaryAction = _ref.secondaryAction,
    primaryAction = _ref.primaryAction,
    customActions = _ref.customActions,
    showBackButton = _ref.showBackButton,
    _ref$showCloseButton = _ref.showCloseButton,
    showCloseButton = _ref$showCloseButton === void 0 ? true : _ref$showCloseButton,
    _ref$showHeaderBorder = _ref.showHeaderBorder,
    showHeaderBorder = _ref$showHeaderBorder === void 0 ? true : _ref$showHeaderBorder,
    _ref$headerHasDefault = _ref.headerHasDefaultPadding,
    headerHasDefaultPadding = _ref$headerHasDefault === void 0 ? true : _ref$headerHasDefault,
    closeOnClickOutside = _ref.closeOnClickOutside,
    onClose = _ref.onClose,
    onBack = _ref.onBack,
    _ref$zIndexOverride = _ref.zIndexOverride,
    zIndexOverride = _ref$zIndexOverride === void 0 ? 999 : _ref$zIndexOverride,
    leftComponent = _ref.leftComponent,
    rightComponent = _ref.rightComponent,
    props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, _excluded);
  var _useState = (0, _react.useState)(false),
    isContentHasScrollbar = _useState[0],
    setIsContentHasScrollbar = _useState[1];
  var modalContentRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(function () {
    var checkScrollbar = function checkScrollbar() {
      var modalContent = modalContentRef.current;
      if (modalContent) {
        setIsContentHasScrollbar(modalContent.scrollHeight > modalContent.clientHeight);
      }
    };
    checkScrollbar();
    var handleResize = function handleResize() {
      return checkScrollbar();
    };
    window.addEventListener('resize', handleResize);
    return function () {
      window.removeEventListener('resize', handleResize);
    };
  });
  (0, _react.useEffect)(function () {
    if (typeof window === 'undefined' || !window.document) return;
    var enableScroll = function enableScroll() {
      document.body.style.overflow = 'unset';
    };
    if (isOpen) {
      document.body.style.overflow = 'hidden';
    } else {
      enableScroll();
    }
    return function () {
      enableScroll();
    };
  }, [isOpen]);
  if (!isOpen) {
    return null;
  }
  var defaultActionContent = /*#__PURE__*/_react["default"].createElement(_ButtonGroup.ButtonGroup, null, secondaryAction && /*#__PURE__*/_react["default"].createElement(_Button.Button, (0, _extends2["default"])({
    onClick: function onClick() {
      return secondaryAction.action == null ? void 0 : secondaryAction.action();
    }
  }, secondaryAction), secondaryAction.label), primaryAction && /*#__PURE__*/_react["default"].createElement(_Button.PrimaryButton, (0, _extends2["default"])({
    onClick: function onClick() {
      return primaryAction.action == null ? void 0 : primaryAction.action();
    }
  }, primaryAction), primaryAction.label));
  var actionsContent = customActions ? customActions : defaultActionContent;
  var hasActions = !!customActions || !!primaryAction || !!secondaryAction;
  var content = typeof children === 'string' ? /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "div",
    variant: "body1"
  }, children) : children;
  var handleClickOutside = function handleClickOutside(event) {
    if (closeOnClickOutside) {
      onClose == null ? void 0 : onClose(event);
    }
  };
  return /*#__PURE__*/_react["default"].createElement(_Portal.Portal, null, /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledModalWrapper, {
    "data-testid": "modal-wrapper",
    onClick: handleClickOutside,
    zIndexOverride: zIndexOverride
  }, leftComponent && /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledModalLeftAndRightComponent, {
    className: "modal-left-component"
  }, leftComponent), /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledModalContainer, (0, _extends2["default"])({
    ref: ref,
    onClick: function onClick(e) {
      return e.stopPropagation();
    }
  }, props), header && /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledModalHeader, {
    "data-show-border": showHeaderBorder,
    "data-header-has-default-padding": headerHasDefaultPadding
  }, showBackButton && /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledButtonContainer, null, /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledModalBackButton, {
    "data-testid": "modal-back-btn",
    "data-has-decription": !!headerDescription,
    onClick: function onClick() {
      return onBack == null ? void 0 : onBack();
    }
  }, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    name: "ri-arrow-left-line"
  }))), /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "div",
    variant: "subtitle1"
  }, header, /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "div",
    variant: "body1"
  }, headerDescription)), showCloseButton && /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledButtonContainer, null, /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledModalCloseButton, {
    "data-testid": "modal-close-btn",
    "data-has-decription": !!headerDescription,
    onClick: onClose
  }, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    name: "ri-close"
  })))), /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledModalContent, {
    className: "modal-content",
    ref: modalContentRef,
    "data-has-scrollbar": isContentHasScrollbar
  }, content), hasActions && /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledModalActions, null, actionsContent)), rightComponent && /*#__PURE__*/_react["default"].createElement(_ModalStyle.StyledModalLeftAndRightComponent, {
    className: "modal-right-component"
  }, rightComponent)));
});
exports.Modal = Modal;