"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.Pagination = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));
var _react = _interopRequireDefault(require("react"));
var _PageButton = require("./PageButton");
var _PaginationStyle = require("./PaginationStyle");
var _paginationUtils = require("./paginationUtils");
var _Stepper = require("./Stepper");
var _excluded = ["value"];
var Pagination = /*#__PURE__*/_react["default"].forwardRef(function Pagination(_ref, ref) {
  var _ref$totalItems = _ref.totalItems,
    totalItems = _ref$totalItems === void 0 ? 1 : _ref$totalItems,
    _ref$currentPage = _ref.currentPage,
    currentPage = _ref$currentPage === void 0 ? 1 : _ref$currentPage,
    disabled = _ref.disabled,
    _ref$pageSize = _ref.pageSize,
    pageSize = _ref$pageSize === void 0 ? _paginationUtils.defaultPageSize : _ref$pageSize,
    onPageChanged = _ref.onPageChanged;
  var pageList = [];
  var totalPages = (0, _paginationUtils.getAllPages)(pageSize, totalItems);
  var bufferSize = (0, _paginationUtils.getBufferSize)(_paginationUtils.defaultBufferSize, totalPages);
  var beginFoldPage = 1 + 2 + bufferSize;
  var endFoldPage = totalPages - 2 - bufferSize;
  var handlePagerClick = function handlePagerClick(value) {
    if (value < 1 || value > totalPages) {
      return;
    }
    onPageChanged == null ? void 0 : onPageChanged(value);
  };
  var Pager = function Pager(_ref2) {
    var value = _ref2.value,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref2, _excluded);
    return /*#__PURE__*/_react["default"].createElement(_PageButton.PageButton, (0, _extends2["default"])({}, props, {
      value: value,
      onClick: handlePagerClick,
      disabled: disabled,
      active: currentPage === value
    }));
  };
  if (
  // beginPage(1 page) + bufferSize * 2 + endPage(1 page) + ...(2 pages)
  totalPages <= 4 + bufferSize * 2 || currentPage === beginFoldPage && currentPage === endFoldPage) {
    for (var i = 1; i <= totalPages; i++) {
      pageList.push( /*#__PURE__*/_react["default"].createElement(Pager, {
        key: i,
        value: i
      }));
    }
  } else {
    var left = 1;
    var right = totalPages;
    var hasJumpPre = true;
    var hasJumpNext = true;
    var calculateNextJumpPage = function calculateNextJumpPage(jumpPage) {
      var minCurrent = totalPages > 0 ? 1 : 0;
      var nextPage = Math.min(totalPages, Math.max(minCurrent, currentPage + jumpPage));
      return nextPage;
    };

    // when first and last page not within reach from current page
    if (currentPage > beginFoldPage && currentPage < endFoldPage) {
      right = currentPage + bufferSize;
      left = currentPage - bufferSize;
      // first page is within reach from current page
    } else if (currentPage <= beginFoldPage) {
      hasJumpPre = false;
      left = 1;
      right = Math.max(beginFoldPage, bufferSize + currentPage);
      // last page within reach from current page
    } else if (currentPage >= endFoldPage) {
      hasJumpNext = false;
      right = totalPages;
      left = Math.min(endFoldPage, currentPage - bufferSize);
    }
    for (var _i = left; _i <= right; _i++) {
      pageList.push( /*#__PURE__*/_react["default"].createElement(Pager, {
        key: _i,
        value: _i
      }));
    }
    var jumpPre = calculateNextJumpPage(-(bufferSize * 2 + 1));
    var jumpNext = calculateNextJumpPage(bufferSize * 2 + 1);
    var FirstPager = /*#__PURE__*/_react["default"].createElement(Pager, {
      value: 1,
      key: 1
    });
    var LastPager = /*#__PURE__*/_react["default"].createElement(Pager, {
      value: totalPages,
      key: totalPages
    });
    if (hasJumpPre) {
      pageList.unshift( /*#__PURE__*/_react["default"].createElement(Pager, {
        key: "jump-pre",
        "data-testid": "previous-jumper",
        value: jumpPre
      }, "..."));
      pageList.unshift(FirstPager);
    }
    if (hasJumpNext) {
      pageList.push( /*#__PURE__*/_react["default"].createElement(Pager, {
        key: "jump-next",
        "data-testid": "next-jumper",
        value: jumpNext
      }, "..."));
      pageList.push(LastPager);
    }
  }
  var hasPrevious = currentPage - 1 > 0;
  var hasNext = currentPage + 1 <= totalPages;
  pageList.unshift( /*#__PURE__*/_react["default"].createElement(_Stepper.PreviousStepper, {
    key: "prev-stepper",
    value: currentPage - 1,
    disabled: !hasPrevious || disabled,
    onClick: handlePagerClick
  }));
  pageList.push( /*#__PURE__*/_react["default"].createElement(_Stepper.NextStepper, {
    key: "next-stepper",
    value: currentPage + 1,
    disabled: !hasNext || disabled,
    onClick: handlePagerClick
  }));
  return /*#__PURE__*/_react["default"].createElement(_PaginationStyle.StyledNav, {
    ref: ref
  }, pageList);
});
exports.Pagination = Pagination;