"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.SearchableSelectInput = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));
var _react = _interopRequireWildcard(require("react"));
var _InputStyle = require("../../../Input/InputStyle");
var _ClearSelected = require("./ClearSelected");
var _SearchableSelectInputStyle = require("./SearchableSelectInputStyle");
var _excluded = ["disabled", "error", "filterOptions", "onSelect", "placeholder", "prefix", "selectedValue", "width", "inputValue", "updateInputValue", "onInputChange", "onBlur", "onFocus", "searchableSelectState", "updateSearchableSelectState", "options", "updateMenuOptions", "border", "borderRadius", "floatingFontSize", "isPlaceholderFloating", "required", "height"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var SearchableSelectInput = /*#__PURE__*/(0, _react.forwardRef)(function SearchableSelectInput(_ref, ref) {
  var _options$find;
  var _ref$disabled = _ref.disabled,
    disabled = _ref$disabled === void 0 ? false : _ref$disabled,
    error = _ref.error,
    filterOptions = _ref.filterOptions,
    onSelect = _ref.onSelect,
    placeholder = _ref.placeholder,
    prefix = _ref.prefix,
    selectedValue = _ref.selectedValue,
    width = _ref.width,
    inputValue = _ref.inputValue,
    updateInputValue = _ref.updateInputValue,
    onInputChange = _ref.onInputChange,
    onBlur = _ref.onBlur,
    onFocus = _ref.onFocus,
    _ref$searchableSelect = _ref.searchableSelectState,
    showInput = _ref$searchableSelect.showInput,
    showPlaceholder = _ref$searchableSelect.showPlaceholder,
    showSelected = _ref$searchableSelect.showSelected,
    updateSearchableSelectState = _ref.updateSearchableSelectState,
    options = _ref.options,
    updateMenuOptions = _ref.updateMenuOptions,
    border = _ref.border,
    borderRadius = _ref.borderRadius,
    floatingFontSize = _ref.floatingFontSize,
    isPlaceholderFloating = _ref.isPlaceholderFloating,
    required = _ref.required,
    height = _ref.height,
    props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, _excluded);
  var inputRef = (0, _react.useRef)(null);
  var _useState = (0, _react.useState)(false),
    showClear = _useState[0],
    setShowClear = _useState[1];
  var _useState2 = (0, _react.useState)(false),
    isSelectedClicked = _useState2[0],
    setIsSelectedClicked = _useState2[1];
  var isShowPlaceholder = showPlaceholder && !isPlaceholderFloating;
  var handleFocus = function handleFocus(e) {
    if (disabled) return;
    setIsSelectedClicked(false);
    setShowClear(false);
    onFocus(e);
  };
  var handleClearIconClick = function handleClearIconClick() {
    if (disabled) return;
    setShowClear(false);
    updateSearchableSelectState({
      showSelected: false,
      showPlaceholder: true,
      showInput: true
    });
    updateMenuOptions(options);
  };
  var handleInputChange = function handleInputChange(e) {
    if (disabled) return;
    var str = e.currentTarget.value;
    if (onInputChange) {
      onInputChange(str);
    }
    updateInputValue(str);
    var filteredOptions = filterOptions(str);
    updateMenuOptions(filteredOptions);
    updateSearchableSelectState({
      showSelected: false,
      showInput: true,
      showPlaceholder: false
    });
  };
  var handleSelectedClick = function handleSelectedClick(e) {
    if (disabled) return;
    e.stopPropagation();
    setIsSelectedClicked(true);
    updateSearchableSelectState({
      showSelected: true,
      showInput: true,
      showPlaceholder: false
    });
    updateInputValue('');
    updateMenuOptions(options);
  };
  var handleInputBlur = function handleInputBlur(e) {
    if (disabled) return;
    setIsSelectedClicked(false);
    if (selectedValue) {
      // allow onClick event handler in Menu before onBlur of input
      setTimeout(function () {
        setShowClear(true);
        updateSearchableSelectState({
          showSelected: true,
          showInput: false,
          showPlaceholder: false
        });
      }, 100);
    }
    onBlur == null ? void 0 : onBlur(e);
  };
  (0, _react.useEffect)(function () {
    if (isSelectedClicked && showInput) {
      inputRef.current.focus();
    }
    return;
  }, [isSelectedClicked, showInput]);
  var handleUpdateSearchableSelectState = _react["default"].useRef(updateSearchableSelectState);
  (0, _react.useEffect)(function () {
    if (selectedValue) {
      setShowClear(true);
      handleUpdateSearchableSelectState.current({
        showSelected: true,
        showInput: false,
        showPlaceholder: false
      });
      return;
    }
    setShowClear(false);
    handleUpdateSearchableSelectState.current({
      showSelected: false,
      showInput: true,
      showPlaceholder: true
    });
  }, [selectedValue, handleUpdateSearchableSelectState]);
  var selectedPlaceholder = required ? placeholder + "*" : placeholder;
  return /*#__PURE__*/_react["default"].createElement(_SearchableSelectInputStyle.StyledContainer, {
    className: "select-input-container",
    ref: ref,
    "data-error": error,
    "data-disabled": disabled,
    prefixWidth: 37,
    suffixWidth: 33,
    width: width,
    height: height,
    isPlaceholderFloating: isPlaceholderFloating
  }, /*#__PURE__*/_react["default"].createElement(_InputStyle.StyledPrefixContainer, {
    height: height
  }, prefix), showSelected && /*#__PURE__*/_react["default"].createElement(_SearchableSelectInputStyle.StyledSelectedValue, {
    className: "searchable-select",
    onClick: handleSelectedClick,
    border: border,
    borderRadius: borderRadius
  }, /*#__PURE__*/_react["default"].createElement(_SearchableSelectInputStyle.StyledSelected, null, ((_options$find = options.find(function (option) {
    return option.value === selectedValue;
  })) == null ? void 0 : _options$find.label) || selectedValue)), showInput && /*#__PURE__*/_react["default"].createElement(_SearchableSelectInputStyle.InputContainer, null, /*#__PURE__*/_react["default"].createElement(_InputStyle.StyledInput, (0, _extends2["default"])({
    ref: inputRef,
    onChange: handleInputChange,
    disabled: disabled,
    placeholder: isShowPlaceholder ? selectedPlaceholder : null,
    value: inputValue,
    onBlur: handleInputBlur,
    onFocus: handleFocus,
    border: border,
    borderRadius: borderRadius
  }, props))), showClear && !disabled && /*#__PURE__*/_react["default"].createElement(_ClearSelected.ClearSelected, {
    onSelect: onSelect,
    handleClearIconClick: handleClearIconClick,
    updateInputValue: updateInputValue,
    height: height
  }), isPlaceholderFloating && /*#__PURE__*/_react["default"].createElement(_InputStyle.FloatingLabel, {
    "data-testid": "textarea-label",
    fontSize: floatingFontSize
  }, placeholder, required && /*#__PURE__*/_react["default"].createElement(_InputStyle.AsteriskIcon, null, "*")));
});
exports.SearchableSelectInput = SearchableSelectInput;