"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.SideSheet = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));
var _react = _interopRequireWildcard(require("react"));
var _Button = require("../Button");
var _ButtonGroup = require("../ButtonGroup");
var _Icon = require("../Icon");
var _colors = require("../utilities/colors");
var _Portal = require("../Portal/Portal");
var _SideSheetStyle = require("./SideSheetStyle");
var _Typography = require("../Typography");
var _classnames = _interopRequireDefault(require("classnames"));
var _excluded = ["isOpen", "title", "description", "showHorizontalLine", "children", "basicButtonAction", "primaryButtonAction", "showBackButton", "onBack", "showCloseButton", "onClose"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var SideSheet = /*#__PURE__*/_react["default"].forwardRef(function SideSheet(_ref, ref) {
  var isOpen = _ref.isOpen,
    title = _ref.title,
    description = _ref.description,
    _ref$showHorizontalLi = _ref.showHorizontalLine,
    showHorizontalLine = _ref$showHorizontalLi === void 0 ? true : _ref$showHorizontalLi,
    children = _ref.children,
    basicButtonAction = _ref.basicButtonAction,
    primaryButtonAction = _ref.primaryButtonAction,
    _ref$showBackButton = _ref.showBackButton,
    showBackButton = _ref$showBackButton === void 0 ? true : _ref$showBackButton,
    onBack = _ref.onBack,
    _ref$showCloseButton = _ref.showCloseButton,
    showCloseButton = _ref$showCloseButton === void 0 ? true : _ref$showCloseButton,
    onClose = _ref.onClose,
    props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, _excluded);
  (0, _react.useEffect)(function () {
    if (typeof window === 'undefined' || !window.document) return;
    var enableScroll = function enableScroll() {
      return document.body.style.overflow = 'unset';
    };
    isOpen ? document.body.style.overflow = 'hidden' : enableScroll();
    return function () {
      enableScroll();
    };
  }, [isOpen]);

  // store state for closing animation, and cleanup when unmounting
  var _useState = (0, _react.useState)(false),
    isClosedAnimation = _useState[0],
    setIsClosedAnimation = _useState[1];
  var timeoutId = (0, _react.useRef)(null);
  (0, _react.useEffect)(function () {
    return function () {
      if (timeoutId.current) {
        clearTimeout(timeoutId.current);
      }
    };
  }, []);

  // fade out effect for 0.2seconds when closed
  var handleClose = function handleClose() {
    setIsClosedAnimation(true);
    timeoutId.current = setTimeout(function () {
      setIsClosedAnimation(false);
      onClose();
    }, 190); // purposefully made this 0.19sec (to prevent rare animation glitch)
  };

  return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, isOpen && /*#__PURE__*/_react["default"].createElement(_Portal.Portal, null, /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledSideSheetWrapper, {
    className: "side-sheet-wrapper " + (isClosedAnimation ? 'closed' : ''),
    onClick: handleClose
  }, /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledSideSheetContainer, (0, _extends2["default"])({
    className: (0, _classnames["default"])({
      closed: isClosedAnimation
    }, 'side-sheet-container'),
    ref: ref,
    onClick: function onClick(e) {
      return e.stopPropagation();
    }
  }, props), /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledSideSheetHeader, null, showBackButton && /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledButtonContainer, {
    onClick: onBack
  }, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    name: "ri-arrow-left-line"
  })), /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "div",
    variant: "subtitle1",
    style: {
      color: _colors.Neutral.B18
    }
  }, title, /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "div",
    variant: "body1",
    style: {
      color: _colors.Neutral.B18
    }
  }, description)), showCloseButton && /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledRightContainer, null, /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledButtonContainer, {
    "data-testid": "sidesheet-close-btn",
    onClick: handleClose
  }, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    name: "ri-close"
  })))), showHorizontalLine && /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledHorizontalLine, null), /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.SideSheetContent, {
    className: "sidesheet-content"
  }, children), (basicButtonAction || primaryButtonAction) && /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledSideSheetFooter, null, /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledHorizontalLine, null), /*#__PURE__*/_react["default"].createElement(_SideSheetStyle.StyledButtonGroupContainer, null, /*#__PURE__*/_react["default"].createElement(_ButtonGroup.ButtonGroup, {
    fullWidth: true
  }, basicButtonAction && /*#__PURE__*/_react["default"].createElement(_Button.Button, (0, _extends2["default"])({}, basicButtonAction, {
    onClick: basicButtonAction.action,
    fullWidth: true
  }), basicButtonAction.label), primaryButtonAction && /*#__PURE__*/_react["default"].createElement(_Button.PrimaryButton, (0, _extends2["default"])({}, primaryButtonAction, {
    onClick: primaryButtonAction.action
  }), primaryButtonAction.label))))))));
});
exports.SideSheet = SideSheet;