"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.Tabs = void 0;
var _reactIdGenerator = _interopRequireDefault(require("react-id-generator"));
var _react = _interopRequireWildcard(require("react"));
var _Tab = require("./Tab");
var _TabStyle = require("./TabStyle");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var Tabs = /*#__PURE__*/_react["default"].forwardRef(function Tabs(_ref, ref) {
  var tabs = _ref.tabs,
    _ref$selected = _ref.selected,
    selectedIndex = _ref$selected === void 0 ? 0 : _ref$selected,
    children = _ref.children,
    fitted = _ref.fitted,
    disabledScrollToTab = _ref.disabledScrollToTab,
    onSelected = _ref.onSelected;
  var tabsHeaderRef = (0, _react.useRef)(null);
  var tabLength = tabs.length;
  var _useState = (0, _react.useState)(0),
    selectedTabIndex = _useState[0],
    setSelectedTabIndex = _useState[1];
  var _useState2 = (0, _react.useState)(false),
    canScrollLeft = _useState2[0],
    setCanScrollLeft = _useState2[1];
  var _useState3 = (0, _react.useState)(false),
    canScrollRight = _useState3[0],
    setCanScrollRight = _useState3[1];
  var _useState4 = (0, _react.useState)(false),
    isDragging = _useState4[0],
    setIsDragging = _useState4[1];
  var _useState5 = (0, _react.useState)(0),
    dragStartX = _useState5[0],
    setDragStartX = _useState5[1];
  var _useState6 = (0, _react.useState)(0),
    scrollLeft = _useState6[0],
    setScrollLeft = _useState6[1];
  (0, _react.useEffect)(function () {
    var element = tabsHeaderRef.current;
    var isElOverFlowX = (element == null ? void 0 : element.scrollWidth) > (element == null ? void 0 : element.clientWidth);
    setCanScrollRight(isElOverFlowX);
  }, []);
  (0, _react.useEffect)(function () {
    if (selectedIndex < 0 || selectedIndex >= tabLength) {
      return;
    }
    setSelectedTabIndex(selectedIndex);
  }, [selectedIndex, tabLength]);
  var handleMouseDown = function handleMouseDown(event) {
    setIsDragging(true);
    var startX = event.clientX - tabsHeaderRef.current.offsetLeft;
    setDragStartX(startX);
    setScrollLeft(tabsHeaderRef.current.scrollLeft);
  };
  var handleMouseLeave = function handleMouseLeave() {
    setIsDragging(false);
  };
  var handleMouseUp = function handleMouseUp() {
    setIsDragging(false);
  };
  var handleMouseMove = function handleMouseMove(event) {
    if (!isDragging) return;
    event.preventDefault();
    var x = event.clientX - tabsHeaderRef.current.offsetLeft;
    var scrollMultiplier = (x - dragStartX) * 3;
    tabsHeaderRef.current.scrollLeft = scrollLeft - scrollMultiplier;
  };
  var handleScroll = function handleScroll() {
    var element = tabsHeaderRef.current;
    setCanScrollLeft((element == null ? void 0 : element.scrollLeft) > 0);
    setCanScrollRight(element.scrollLeft < element.scrollWidth - element.clientWidth);
  };
  var handleWheel = function handleWheel(event) {
    var element = tabsHeaderRef.current;
    element.scrollTo({
      left: element.scrollLeft + event.deltaY * 1,
      behavior: 'smooth'
    });
  };
  var handleSelectedIndexChanged = function handleSelectedIndexChanged(index) {
    setSelectedTabIndex(index);
    onSelected == null ? void 0 : onSelected(index);
  };
  var renderTabs = tabs.map(function (tab, index) {
    var tabId = tab.id || (0, _reactIdGenerator["default"])();
    var tabContent = /*#__PURE__*/_react["default"].createElement(_Tab.Tab, {
      id: tabId,
      key: "tab-" + tabId + "-" + index,
      content: tab.content,
      onSelect: function onSelect() {
        return handleSelectedIndexChanged(index);
      },
      selected: index === selectedTabIndex,
      disabled: tab.disabled,
      disabledScrollToTab: disabledScrollToTab
    });
    return /*#__PURE__*/_react["default"].createElement(_TabStyle.StyledLi, {
      key: tabId + "-" + index,
      className: "tab-item"
    }, tab.contentWrapper ? tab.contentWrapper(tabContent) : tabContent);
  });
  return /*#__PURE__*/_react["default"].createElement(_TabStyle.StyledTabsContainer, {
    ref: ref,
    className: "tabs-container"
  }, /*#__PURE__*/_react["default"].createElement(_TabStyle.StyledTabHeaderContainer, {
    className: "tabs-header-container",
    ref: tabsHeaderRef,
    onScroll: handleScroll,
    onWheel: handleWheel,
    onMouseDown: handleMouseDown,
    onMouseMove: handleMouseMove,
    onMouseUp: handleMouseUp,
    onMouseLeave: handleMouseLeave,
    "data-scroll-left": canScrollLeft,
    "data-scroll-right": canScrollRight,
    "data-grabbing": isDragging
  }, /*#__PURE__*/_react["default"].createElement(_TabStyle.StyledUl, {
    "data-fitted": fitted,
    className: "tabs-list"
  }, renderTabs)), /*#__PURE__*/_react["default"].createElement("div", {
    className: "tab-item-content"
  }, children));
});
exports.Tabs = Tabs;