"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.TextArea = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));
var _react = _interopRequireWildcard(require("react"));
var _TextAreaStyle = require("./TextAreaStyle");
var _Typography = require("../Typography");
var _InputStyle = require("../Input/InputStyle");
var _excluded = ["value", "rows", "maxLength", "error", "disabled", "width", "onChange", "forwardedRef", "canExceedMaxLength", "required", "border", "borderRadius", "isPlaceholderFloating", "floatingFontSize", "placeholder", "floatingPlaceholderTop", "placeholderColor"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var _TextArea = function _TextArea(_ref) {
  var value = _ref.value,
    _ref$rows = _ref.rows,
    rows = _ref$rows === void 0 ? 3 : _ref$rows,
    maxLength = _ref.maxLength,
    _ref$error = _ref.error,
    error = _ref$error === void 0 ? false : _ref$error,
    _ref$disabled = _ref.disabled,
    disabled = _ref$disabled === void 0 ? false : _ref$disabled,
    _ref$width = _ref.width,
    width = _ref$width === void 0 ? '520px' : _ref$width,
    onChange = _ref.onChange,
    forwardedRef = _ref.forwardedRef,
    _ref$canExceedMaxLeng = _ref.canExceedMaxLength,
    canExceedMaxLength = _ref$canExceedMaxLeng === void 0 ? true : _ref$canExceedMaxLeng,
    required = _ref.required,
    border = _ref.border,
    borderRadius = _ref.borderRadius,
    isPlaceholderFloating = _ref.isPlaceholderFloating,
    floatingFontSize = _ref.floatingFontSize,
    placeholder = _ref.placeholder,
    floatingPlaceholderTop = _ref.floatingPlaceholderTop,
    placeholderColor = _ref.placeholderColor,
    props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, _excluded);
  var _useState = (0, _react.useState)(false),
    isFocused = _useState[0],
    setIsFocused = _useState[1];
  var charCount = value.length;
  var hasMaxLengthEnforced = maxLength > 0;
  var hasError = error || canExceedMaxLength && charCount > maxLength;
  var localRef = (0, _react.useRef)(null);
  var textAreaInputRef = forwardedRef || localRef;
  var handleContainerClick = function handleContainerClick() {
    if (textAreaInputRef.current) {
      textAreaInputRef.current.focus();
    }
  };
  var handleChange = function handleChange(e) {
    var val = e.currentTarget.value;
    onChange(val);
  };
  return /*#__PURE__*/_react["default"].createElement(_TextAreaStyle.StyledTextAreaContainer, {
    "data-error": hasError,
    "data-disabled": disabled,
    "data-focus": isFocused,
    "data-has-counter": hasMaxLengthEnforced,
    width: width,
    onClick: handleContainerClick,
    border: border,
    borderRadius: borderRadius,
    isPlaceholderFloating: isPlaceholderFloating
  }, /*#__PURE__*/_react["default"].createElement(_TextAreaStyle.StyledTextArea, (0, _extends2["default"])({
    ref: textAreaInputRef,
    value: value,
    rows: rows,
    width: width,
    onChange: handleChange,
    disabled: disabled,
    maxLength: !canExceedMaxLength && maxLength,
    onFocus: function onFocus() {
      return setIsFocused(true);
    },
    onBlur: function onBlur() {
      return setIsFocused(false);
    },
    border: border,
    borderRadius: borderRadius,
    placeholder: isPlaceholderFloating && !disabled ? undefined : placeholder
  }, props)), hasMaxLengthEnforced && /*#__PURE__*/_react["default"].createElement(_TextAreaStyle.StyledWordCountContainer, {
    "data-disabled": disabled,
    "data-error": hasError
  }, /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "span",
    variant: "overline"
  }, charCount, " / ", maxLength)), isPlaceholderFloating && !disabled && /*#__PURE__*/_react["default"].createElement(_InputStyle.FloatingLabel, {
    "data-testid": "textarea-label",
    "data-error": error,
    fontSize: floatingFontSize,
    color: placeholderColor,
    top: floatingPlaceholderTop
  }, placeholder, required && /*#__PURE__*/_react["default"].createElement(_InputStyle.AsteriskIcon, null, "*")));
};
var forwardRef = function forwardRef(props, ref) {
  return /*#__PURE__*/_react["default"].createElement(_TextArea, (0, _extends2["default"])({}, props, {
    forwardedRef: ref
  }));
};
forwardRef.displayName = _TextArea.name;
var TextArea = /*#__PURE__*/_react["default"].forwardRef(forwardRef);
exports.TextArea = TextArea;