"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.Tooltip = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));
var _react = _interopRequireWildcard(require("react"));
var _Portal = require("../Portal/Portal");
var _Typography = require("../Typography");
var _positionResolver = require("./positionResolver");
var _positionResolverHelper = require("./positionResolverHelper");
var _TooltipStyle = require("./TooltipStyle");
var _classnames = _interopRequireDefault(require("classnames"));
var _excluded = ["children", "content", "preferredPosition", "zIndex", "clickable", "timeout", "onClick", "tooltipClassName"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var topPositions = ['top-center', 'top-left', 'top-right'];
var bottomPositions = ['bottom-center', 'bottom-left', 'bottom-right'];
var rightPositions = ['right-middle', 'right-top', 'right-bottom'];
var leftPositions = ['left-middle', 'left-top', 'left-bottom'];
var allPositions = [].concat(topPositions, bottomPositions, rightPositions, leftPositions);
var tooltipPositionResolvers = {
  'top-center': function topCenter(tooltipRect, elementRect) {
    return (0, _positionResolver.topPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignCenter, _positionResolverHelper.canAlignLeft, _positionResolverHelper.canAlignRight]);
  },
  'top-left': function topLeft(tooltipRect, elementRect) {
    return (0, _positionResolver.topPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignLeft, _positionResolverHelper.canAlignCenter, _positionResolverHelper.canAlignRight]);
  },
  'top-right': function topRight(tooltipRect, elementRect) {
    return (0, _positionResolver.topPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignRight, _positionResolverHelper.canAlignCenter, _positionResolverHelper.canAlignLeft]);
  },
  'bottom-center': function bottomCenter(tooltipRect, elementRect) {
    return (0, _positionResolver.bottomPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignCenter, _positionResolverHelper.canAlignLeft, _positionResolverHelper.canAlignRight]);
  },
  'bottom-left': function bottomLeft(tooltipRect, elementRect) {
    return (0, _positionResolver.bottomPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignLeft, _positionResolverHelper.canAlignCenter, _positionResolverHelper.canAlignRight]);
  },
  'bottom-right': function bottomRight(tooltipRect, elementRect) {
    return (0, _positionResolver.bottomPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignRight, _positionResolverHelper.canAlignCenter, _positionResolverHelper.canAlignLeft]);
  },
  'right-middle': function rightMiddle(tooltipRect, elementRect) {
    return (0, _positionResolver.rightPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignMiddle, _positionResolverHelper.canAlignTop, _positionResolverHelper.canAlignBottom]);
  },
  'right-top': function rightTop(tooltipRect, elementRect) {
    return (0, _positionResolver.rightPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignTop, _positionResolverHelper.canAlignMiddle, _positionResolverHelper.canAlignBottom]);
  },
  'right-bottom': function rightBottom(tooltipRect, elementRect) {
    return (0, _positionResolver.rightPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignBottom, _positionResolverHelper.canAlignMiddle, _positionResolverHelper.canAlignTop]);
  },
  'left-middle': function leftMiddle(tooltipRect, elementRect) {
    return (0, _positionResolver.leftPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignMiddle, _positionResolverHelper.canAlignTop, _positionResolverHelper.canAlignBottom]);
  },
  'left-top': function leftTop(tooltipRect, elementRect) {
    return (0, _positionResolver.leftPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignTop, _positionResolverHelper.canAlignMiddle, _positionResolverHelper.canAlignBottom]);
  },
  'left-bottom': function leftBottom(tooltipRect, elementRect) {
    return (0, _positionResolver.leftPositionResolver)(tooltipRect, elementRect, [_positionResolverHelper.canAlignBottom, _positionResolverHelper.canAlignMiddle, _positionResolverHelper.canAlignTop]);
  }
};
var defaultPosition = 'top-center';
var Tooltip = function Tooltip(_ref) {
  var children = _ref.children,
    content = _ref.content,
    _ref$preferredPositio = _ref.preferredPosition,
    preferredPosition = _ref$preferredPositio === void 0 ? defaultPosition : _ref$preferredPositio,
    zIndex = _ref.zIndex,
    _ref$clickable = _ref.clickable,
    clickable = _ref$clickable === void 0 ? false : _ref$clickable,
    _ref$timeout = _ref.timeout,
    timeout = _ref$timeout === void 0 ? 0 : _ref$timeout,
    onClick = _ref.onClick,
    tooltipClassName = _ref.tooltipClassName,
    props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, _excluded);
  var tooltipRef = (0, _react.useRef)(null);
  var elRef = (0, _react.useRef)(null);
  var tooltipPositionsHandlerRef = (0, _react.useRef)(null);
  var _useState = (0, _react.useState)(null),
    toolTipCoord = _useState[0],
    setToolTipCoord = _useState[1];
  var _useState2 = (0, _react.useState)(false),
    isActive = _useState2[0],
    setIsActive = _useState2[1];
  var _useState3 = (0, _react.useState)(null),
    overridePosition = _useState3[0],
    setOverridePosition = _useState3[1];
  if (!allPositions.includes(preferredPosition)) {
    preferredPosition = defaultPosition;
    console.warn("\"" + preferredPosition + "\" is not a valid tooltip positon, \"" + defaultPosition + "\" will be used instead");
  }
  var position = overridePosition || preferredPosition;
  var handleTooltipPositions = function handleTooltipPositions(tooltipRect, elRect, currentPosition) {
    var resolver = tooltipPositionResolvers[position] || tooltipPositionResolvers[defaultPosition];
    var newLeft = 0;
    var newTop = 0;
    if (position.startsWith('top')) {
      newTop = elRect.top - tooltipRect.height - _positionResolverHelper.verticalBuffer;
      newLeft = elRect.left + elRect.width / 2;
    }
    if (position.startsWith('bottom')) {
      newTop = elRect.top + elRect.height + _positionResolverHelper.verticalBuffer;
      newLeft = elRect.left + elRect.width / 2;
    }
    if (position.startsWith('left')) {
      newTop = elRect.top + elRect.height / 2;
      newLeft = elRect.left - tooltipRect.width - _positionResolverHelper.horizontalBuffer;
    }
    if (position.startsWith('right')) {
      newTop = elRect.top + elRect.height / 2;
      newLeft = elRect.left + elRect.width + _positionResolverHelper.horizontalBuffer;
    }
    setToolTipCoord({
      top: newTop,
      left: newLeft
    });
    var tooltipRectNew = new DOMRect(newLeft, newTop, tooltipRect.width, tooltipRect.height);
    var resolvedPosition = resolver(tooltipRectNew, elRect);
    if (!overridePosition && resolvedPosition !== currentPosition) {
      setOverridePosition(resolvedPosition);
    }
  };
  tooltipPositionsHandlerRef.current = handleTooltipPositions;
  (0, _react.useEffect)(function () {
    if (isActive) {
      var _tooltipRef$current, _elRef$current;
      tooltipPositionsHandlerRef.current(tooltipRef == null ? void 0 : (_tooltipRef$current = tooltipRef.current) == null ? void 0 : _tooltipRef$current.getClientRects()[0], elRef == null ? void 0 : (_elRef$current = elRef.current) == null ? void 0 : _elRef$current.getClientRects()[0], position);
    }
  }, [isActive, position]);
  var contentMarkup = typeof content === 'string' ? /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "div",
    variant: "subtitle2"
  }, content) : content;
  var handleMouseEnter = function handleMouseEnter() {
    if (!clickable) setIsActive(true);
  };
  var handleMouseLeave = function handleMouseLeave() {
    if (!clickable) {
      setIsActive(false);
      handleAnimation();
    }
  };
  var handleClick = function handleClick() {
    if (clickable) {
      onClick();
      handleAnimation();
    }
  };
  var timeoutRef = (0, _react.useRef)(null);
  var _useState4 = (0, _react.useState)(false),
    animate = _useState4[0],
    setAnimate = _useState4[1];
  var handleAnimation = function handleAnimation() {
    // if you click during the tooltip's lifespan, it should reset the timeout
    if (timeoutRef.current) {
      clearTimeout(timeoutRef.current);
      timeoutRef.current = null;
      setAnimate(false);
    }
    setIsActive(true);
    timeoutRef.current = setTimeout(function () {
      setAnimate(true);
      timeoutRef.current = setTimeout(function () {
        setIsActive(false);
        setAnimate(false);
      }, 370); // animation is 400ms, make this slightly lower to prevent visual glitch
    }, timeout);
  };
  return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(_TooltipStyle.StyledTooltipContainer, (0, _extends2["default"])({
    ref: elRef,
    onMouseEnter: handleMouseEnter,
    onMouseLeave: handleMouseLeave,
    onClick: handleClick
  }, props), children), isActive && /*#__PURE__*/_react["default"].createElement(_Portal.Portal, null, /*#__PURE__*/_react["default"].createElement(_TooltipStyle.StyledTooltip, {
    "data-position": position,
    className: (0, _classnames["default"])({
      'closed-animation': animate
    }, tooltipClassName),
    ref: tooltipRef,
    zIndex: zIndex,
    style: {
      top: (toolTipCoord == null ? void 0 : toolTipCoord.top) + 'px',
      left: (toolTipCoord == null ? void 0 : toolTipCoord.left) + 'px',
      visibility: toolTipCoord ? 'visible' : 'hidden'
    }
  }, /*#__PURE__*/_react["default"].createElement(_TooltipStyle.StyledTooltipArrow, {
    className: "arrow"
  }), contentMarkup)));
};
exports.Tooltip = Tooltip;