"use strict";

exports.__esModule = true;
exports.topPositionResolver = exports.rightPositionResolver = exports.leftPositionResolver = exports.bottomPositionResolver = void 0;
var _positionResolverHelper = require("./positionResolverHelper");
var topPositionResolver = function topPositionResolver(tooltipRect, elRect, preferredAligmentFuncs) {
  var horizontalPreferredAligmentFuncs = preferredAligmentFuncs;
  var verticalPreferredAligmentFuncs = [_positionResolverHelper.canAlignMiddle, _positionResolverHelper.canAlignTop, _positionResolverHelper.canAlignBottom];
  if ((0, _positionResolverHelper.canStayOnTop)(tooltipRect)) {
    var alignResult = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (alignResult) {
      return "top-" + alignResult;
    }
  }
  if ((0, _positionResolverHelper.canFitOnTheLeft)(tooltipRect, elRect, _positionResolverHelper.horizontalBuffer)) {
    var _alignResult = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult) {
      return "left-" + _alignResult;
    }
  }
  if ((0, _positionResolverHelper.canFitOnTheRight)(tooltipRect, elRect, _positionResolverHelper.horizontalBuffer)) {
    var _alignResult2 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult2) {
      return "right-" + _alignResult2;
    }
  }
  if ((0, _positionResolverHelper.canFitBelow)(tooltipRect, elRect, _positionResolverHelper.verticalBuffer)) {
    var _alignResult3 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult3) {
      return "bottom-" + _alignResult3;
    }
  }
  return 'top-center';
};
exports.topPositionResolver = topPositionResolver;
var bottomPositionResolver = function bottomPositionResolver(tooltipRect, elRect, preferredAligmentFuncs) {
  var horizontalPreferredAligmentFuncs = preferredAligmentFuncs;
  var verticalPreferredAligmentFuncs = [_positionResolverHelper.canAlignMiddle, _positionResolverHelper.canAlignTop, _positionResolverHelper.canAlignBottom];
  if ((0, _positionResolverHelper.canStayOnBottom)(tooltipRect)) {
    var alignResult = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (alignResult) {
      return "bottom-" + alignResult;
    }
  }
  if ((0, _positionResolverHelper.canFitOnTheLeft)(tooltipRect, elRect, _positionResolverHelper.horizontalBuffer)) {
    var _alignResult4 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult4) {
      return "left-" + _alignResult4;
    }
  }
  if ((0, _positionResolverHelper.canFitOnTheRight)(tooltipRect, elRect, _positionResolverHelper.horizontalBuffer)) {
    var _alignResult5 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult5) {
      return "right-" + _alignResult5;
    }
  }
  if ((0, _positionResolverHelper.canFitOnTheTop)(tooltipRect, elRect, _positionResolverHelper.verticalBuffer)) {
    var _alignResult6 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult6) {
      return "top-" + _alignResult6;
    }
  }
  return 'bottom-center';
};
exports.bottomPositionResolver = bottomPositionResolver;
var leftPositionResolver = function leftPositionResolver(tooltipRect, elRect, preferredAligmentFuncs) {
  var horizontalPreferredAligmentFuncs = [_positionResolverHelper.canAlignCenter, _positionResolverHelper.canAlignLeft, _positionResolverHelper.canAlignRight];
  var verticalPreferredAligmentFuncs = preferredAligmentFuncs;
  if ((0, _positionResolverHelper.canStayOnLeft)(tooltipRect)) {
    var alignResult = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (alignResult) {
      return "left-" + alignResult;
    }
  }
  if ((0, _positionResolverHelper.canFitOnTheTop)(tooltipRect, elRect, _positionResolverHelper.horizontalBuffer)) {
    var _alignResult7 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult7) {
      return "top-" + _alignResult7;
    }
  }
  if ((0, _positionResolverHelper.canFitOnTheRight)(tooltipRect, elRect, _positionResolverHelper.horizontalBuffer)) {
    var _alignResult8 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult8) {
      return "right-" + _alignResult8;
    }
  }
  if ((0, _positionResolverHelper.canFitBelow)(tooltipRect, elRect, _positionResolverHelper.verticalBuffer)) {
    var _alignResult9 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult9) {
      return "bottom-" + _alignResult9;
    }
  }
  return 'left-middle';
};
exports.leftPositionResolver = leftPositionResolver;
var rightPositionResolver = function rightPositionResolver(tooltipRect, elRect, preferredAligmentFuncs) {
  var horizontalPreferredAligmentFuncs = [_positionResolverHelper.canAlignCenter, _positionResolverHelper.canAlignLeft, _positionResolverHelper.canAlignRight];
  var verticalPreferredAligmentFuncs = preferredAligmentFuncs;
  if ((0, _positionResolverHelper.canStayOnRight)(tooltipRect)) {
    var alignResult = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (alignResult) {
      return "right-" + alignResult;
    }
  }
  if ((0, _positionResolverHelper.canFitOnTheTop)(tooltipRect, elRect, _positionResolverHelper.horizontalBuffer)) {
    var _alignResult10 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult10) {
      return "top-" + _alignResult10;
    }
  }
  if ((0, _positionResolverHelper.canFitOnTheLeft)(tooltipRect, elRect, _positionResolverHelper.horizontalBuffer)) {
    var _alignResult11 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: verticalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult11) {
      return "left-" + _alignResult11;
    }
  }
  if ((0, _positionResolverHelper.canFitBelow)(tooltipRect, elRect, _positionResolverHelper.verticalBuffer)) {
    var _alignResult12 = (0, _positionResolverHelper.tryCalculateAligment)({
      preferredAlignmentFuncs: horizontalPreferredAligmentFuncs,
      tooltipRect: tooltipRect,
      elRect: elRect
    });
    if (_alignResult12) {
      return "bottom-" + _alignResult12;
    }
  }
  return 'right-middle';
};
exports.rightPositionResolver = rightPositionResolver;