"use strict";

exports.__esModule = true;
exports.verticalBuffer = exports.tryCalculateAligment = exports.nonCenterArrowSpace = exports.horizontalBuffer = exports.getElementMiddlePosition = exports.getElementCenterPosition = exports.canStayOnTop = exports.canStayOnRight = exports.canStayOnLeft = exports.canStayOnBottom = exports.canFitOnTheTop = exports.canFitOnTheRight = exports.canFitOnTheLeft = exports.canFitBelow = exports.canAlignTop = exports.canAlignRight = exports.canAlignMiddle = exports.canAlignLeft = exports.canAlignCenter = exports.canAlignBottom = void 0;
var _viewPort = require("../../helpers/viewPort");
function _createForOfIteratorHelperLoose(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (it) return (it = it.call(o)).next.bind(it); if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; return function () { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
var verticalBuffer = 8;
exports.verticalBuffer = verticalBuffer;
var horizontalBuffer = 8;
exports.horizontalBuffer = horizontalBuffer;
var nonCenterArrowSpace = 12;
// for non center position the position of the arrow is 12px from the most left or right, setting it to 14 to make sure it's nicely visible
exports.nonCenterArrowSpace = nonCenterArrowSpace;
var marginBuffer = nonCenterArrowSpace + 2;
var getElementCenterPosition = function getElementCenterPosition(elRect) {
  return elRect.left + elRect.width / 2;
};
exports.getElementCenterPosition = getElementCenterPosition;
var getElementMiddlePosition = function getElementMiddlePosition(elRect) {
  return elRect.bottom + elRect.height / 2;
};
exports.getElementMiddlePosition = getElementMiddlePosition;
var canFitOnTheTop = function canFitOnTheTop(tooltipRect, elRect, verticalMargin) {
  return elRect.top - (verticalMargin + tooltipRect.height) > 0;
};
exports.canFitOnTheTop = canFitOnTheTop;
var canFitBelow = function canFitBelow(tooltipRect, elRect, verticalMargin) {
  return elRect.bottom + verticalMargin + tooltipRect.height < (0, _viewPort.getViewportDimensions)().height;
};
exports.canFitBelow = canFitBelow;
var canFitOnTheLeft = function canFitOnTheLeft(tooltipRect, elRect, horizontalMargin) {
  return elRect.left - (horizontalMargin + tooltipRect.width) > 0;
};
exports.canFitOnTheLeft = canFitOnTheLeft;
var canFitOnTheRight = function canFitOnTheRight(tooltipRect, elRect, horizontalMargin) {
  return elRect.right + horizontalMargin + tooltipRect.width < (0, _viewPort.getViewportDimensions)().width;
};
exports.canFitOnTheRight = canFitOnTheRight;
var canAlignLeft = function canAlignLeft(tooltipRect, elRect) {
  var centerPosition = getElementCenterPosition(elRect);
  var hasSpaceOnTheLeftSideOfArrow = centerPosition - (tooltipRect.width - marginBuffer) > 0;
  var hasSpaceOnTheRightSideOfArrow = centerPosition + marginBuffer < (0, _viewPort.getViewportDimensions)().width;
  return {
    type: 'left',
    result: hasSpaceOnTheLeftSideOfArrow && hasSpaceOnTheRightSideOfArrow
  };
};
exports.canAlignLeft = canAlignLeft;
var canAlignRight = function canAlignRight(tooltipRect, elRect) {
  var centerPosition = getElementCenterPosition(elRect);
  var hasSpaceOnTheRightSideOfArrow = centerPosition + (tooltipRect.width - marginBuffer) < (0, _viewPort.getViewportDimensions)().width;
  var hasSpaceOnTheLeftSideOfArrow = centerPosition - marginBuffer > 0;
  return {
    type: 'right',
    result: hasSpaceOnTheLeftSideOfArrow && hasSpaceOnTheRightSideOfArrow
  };
};
exports.canAlignRight = canAlignRight;
var canAlignCenter = function canAlignCenter(tooltipRect, elRect) {
  var centerPosition = elRect.left + elRect.width / 2;
  return {
    type: 'center',
    result: centerPosition - tooltipRect.width / 2 > 0 && centerPosition + tooltipRect.width / 2 < (0, _viewPort.getViewportDimensions)().width
  };
};
exports.canAlignCenter = canAlignCenter;
var canAlignTop = function canAlignTop(tooltipRect, elRect) {
  var middlePosition = getElementMiddlePosition(elRect);
  var hasSpaceOnTheTopOfArrow = middlePosition - (tooltipRect.height - marginBuffer) > 0;
  var hasSpaceBelowTheArrow = middlePosition + marginBuffer < (0, _viewPort.getViewportDimensions)().width;
  return {
    type: 'top',
    result: hasSpaceOnTheTopOfArrow && hasSpaceBelowTheArrow
  };
};
exports.canAlignTop = canAlignTop;
var canAlignBottom = function canAlignBottom(tooltipRect, elRect) {
  var middlePosition = getElementMiddlePosition(elRect);
  var hasSpaceOnTopOfArrow = middlePosition + (tooltipRect.height - marginBuffer) < (0, _viewPort.getViewportDimensions)().height;
  var hasSpaceBelowTheArrow = middlePosition - marginBuffer > 0;
  return {
    type: 'bottom',
    result: hasSpaceBelowTheArrow && hasSpaceOnTopOfArrow
  };
};
exports.canAlignBottom = canAlignBottom;
var canAlignMiddle = function canAlignMiddle(tooltipRect, elRect) {
  var middlePosition = elRect.top + elRect.height / 2;
  return {
    type: 'middle',
    result: middlePosition - tooltipRect.height / 2 > 0 && middlePosition + tooltipRect.height / 2 < (0, _viewPort.getViewportDimensions)().height
  };
};
exports.canAlignMiddle = canAlignMiddle;
var canStayOnTop = function canStayOnTop(tooltipRect) {
  return tooltipRect.top > 0;
};
exports.canStayOnTop = canStayOnTop;
var canStayOnBottom = function canStayOnBottom(tooltipRect) {
  console.log('tooltipRect:', tooltipRect);
  console.log('getViewportDimensions().height: ', (0, _viewPort.getViewportDimensions)().height);
  return tooltipRect.bottom < (0, _viewPort.getViewportDimensions)().height;
};
exports.canStayOnBottom = canStayOnBottom;
var canStayOnLeft = function canStayOnLeft(tooltipRect) {
  return tooltipRect.left > 0;
};
exports.canStayOnLeft = canStayOnLeft;
var canStayOnRight = function canStayOnRight(tooltipRect) {
  return tooltipRect.right < (0, _viewPort.getViewportDimensions)().width;
};
exports.canStayOnRight = canStayOnRight;
var tryCalculateAligment = function tryCalculateAligment(args) {
  var preferredAlignmentFuncs = args.preferredAlignmentFuncs,
    tooltipRect = args.tooltipRect,
    elRect = args.elRect;
  for (var _iterator = _createForOfIteratorHelperLoose(preferredAlignmentFuncs), _step; !(_step = _iterator()).done;) {
    var alignmentFunc = _step.value;
    var _alignmentFunc = alignmentFunc(tooltipRect, elRect),
      result = _alignmentFunc.result,
      type = _alignmentFunc.type;
    if (result) {
      return type;
    }
  }
  return null;
};
exports.tryCalculateAligment = tryCalculateAligment;