"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.Upload = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));
var _react = _interopRequireWildcard(require("react"));
var _Icon = require("../Icon");
var _UploadStyle = require("./UploadStyle");
var _Spinner = require("../Spinner");
var _Typography = require("../Typography");
var _excluded = ["file", "handleSetFile", "loading", "objectFit", "uploadMessage", "loadingMessage", "disableDefaultValidation", "accept"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var Upload = /*#__PURE__*/_react["default"].forwardRef(function Upload(_ref, ref) {
  var file = _ref.file,
    handleSetFile = _ref.handleSetFile,
    loading = _ref.loading,
    _ref$objectFit = _ref.objectFit,
    objectFit = _ref$objectFit === void 0 ? 'cover' : _ref$objectFit,
    _ref$uploadMessage = _ref.uploadMessage,
    uploadMessage = _ref$uploadMessage === void 0 ? 'Upload' : _ref$uploadMessage,
    _ref$loadingMessage = _ref.loadingMessage,
    loadingMessage = _ref$loadingMessage === void 0 ? 'loading...' : _ref$loadingMessage,
    _ref$disableDefaultVa = _ref.disableDefaultValidation,
    disableDefaultValidation = _ref$disableDefaultVa === void 0 ? false : _ref$disableDefaultVa,
    accept = _ref.accept,
    props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, _excluded);
  var MAX_FILE_SIZE = 5; // in MB

  var _useState = (0, _react.useState)(''),
    attachmentUrl = _useState[0],
    setAttachmentUrl = _useState[1];
  var _useState2 = (0, _react.useState)(loading),
    isLoading = _useState2[0],
    setIsLoading = _useState2[1];
  var _useState3 = (0, _react.useState)(''),
    error = _useState3[0],
    setError = _useState3[1];
  var fileInputRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(function () {
    var reader = new FileReader();
    reader.onloadend = function () {
      setAttachmentUrl(reader.result);
      setIsLoading(false);
    };
    reader.onloadstart = function () {
      return setIsLoading(true);
    };
    if (file) reader.readAsDataURL(file);
  }, [file, loading]);
  var handleClick = function handleClick() {
    if (fileInputRef.current) {
      fileInputRef.current.click();
    }
  };
  var handleChange = function handleChange(event) {
    var _event$target$files;
    var newFile = (_event$target$files = event.target.files) == null ? void 0 : _event$target$files[0];
    if (disableDefaultValidation) {
      var _event$target$files2;
      handleSetFile(((_event$target$files2 = event.target.files) == null ? void 0 : _event$target$files2[0]) || null);
      return;
    }
    if (newFile && !newFile.type.startsWith('image')) {
      setError('Image required');
      handleSetFile(null);
    } else if (newFile && newFile.size > MAX_FILE_SIZE * 1024 * 1024) {
      setError('File too big');
      handleSetFile(null);
    } else {
      setError('');
      handleSetFile(newFile);
    }
  };
  var handleDelete = function handleDelete() {
    setAttachmentUrl('');
    handleSetFile(null);
    fileInputRef.current.value = null;
  };
  var unuploadedComponent = /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledUploadContainer, {
    onClick: handleClick,
    "data-type": "initial",
    "data-error": !!error,
    "data-testid": "upload-container"
  }, /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledIconContainer, null, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    name: "ri-add"
  })), /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledTextContainer, null, /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "span",
    variant: "button"
  }, uploadMessage)));
  var loadingComponent = /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledUploadContainer, {
    "data-type": "loading"
  }, /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledIconContainer, {
    "data-type": "loading"
  }, /*#__PURE__*/_react["default"].createElement(_Spinner.Spinner, null)), /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledTextContainer, null, /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "span",
    variant: "overline"
  }, loadingMessage)));
  var errorComponent = /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledErrorContainer, null, /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledErrorIconContainer, null, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    name: "ri-error-warning-fill"
  })), /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledErrorTextContainer, null, /*#__PURE__*/_react["default"].createElement(_Typography.Typography, {
    as: "span",
    variant: "subtitle2"
  }, error)));
  var uploadedImageComponent = /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledUploadedImage, {
    src: attachmentUrl,
    objectFit: objectFit
  });
  return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledInvisibleInput, (0, _extends2["default"])({
    type: "file",
    accept: accept || 'image/*',
    onChange: handleChange,
    ref: ref || fileInputRef
  }, props)), attachmentUrl && !(loading || isLoading) ? /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledUploadContainer, {
    "data-type": "image",
    "data-testid": "upload-container"
  }, uploadedImageComponent, /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledDeleteButtonContainer, {
    onClick: handleDelete
  }, /*#__PURE__*/_react["default"].createElement(_UploadStyle.StyledDeleteIconContainer, null, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    name: "ri-delete-bin-line"
  })))) : /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, loading || isLoading ? /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, loadingComponent) : /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, unuploadedComponent), !!error && /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, errorComponent)));
});
exports.Upload = Upload;